// Code generated by protoc-gen-connect-go. DO NOT EDIT.
//
// Source: tars/admin/v1/admin.proto

package adminv1connect

import (
	connect "connectrpc.com/connect"
	context "context"
	errors "errors"
	v1 "github.com/tetrateio/agentrouter-go/genapi/api/tars/admin/v1"
	http "net/http"
	strings "strings"
)

// This is a compile-time assertion to ensure that this generated file and the connect package are
// compatible. If you get a compiler error that this constant is not defined, this code was
// generated with a version of connect newer than the one compiled into your binary. You can fix the
// problem by either regenerating this code with an older version of connect or updating the connect
// version compiled into your binary.
const _ = connect.IsAtLeastVersion1_13_0

const (
	// AdminServiceName is the fully-qualified name of the AdminService service.
	AdminServiceName = "tars.admin.v1.AdminService"
)

// These constants are the fully-qualified names of the RPCs defined in this package. They're
// exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
//
// Note that these are different from the fully-qualified method names used by
// google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to
// reflection-formatted method names, remove the leading slash and convert the remaining slash to a
// period.
const (
	// AdminServicePingProcedure is the fully-qualified name of the AdminService's Ping RPC.
	AdminServicePingProcedure = "/tars.admin.v1.AdminService/Ping"
	// AdminServiceCreateWorkspaceProcedure is the fully-qualified name of the AdminService's
	// CreateWorkspace RPC.
	AdminServiceCreateWorkspaceProcedure = "/tars.admin.v1.AdminService/CreateWorkspace"
	// AdminServiceListWorkspacesProcedure is the fully-qualified name of the AdminService's
	// ListWorkspaces RPC.
	AdminServiceListWorkspacesProcedure = "/tars.admin.v1.AdminService/ListWorkspaces"
	// AdminServiceGetWorkspaceProcedure is the fully-qualified name of the AdminService's GetWorkspace
	// RPC.
	AdminServiceGetWorkspaceProcedure = "/tars.admin.v1.AdminService/GetWorkspace"
	// AdminServiceUpdateWorkspaceProcedure is the fully-qualified name of the AdminService's
	// UpdateWorkspace RPC.
	AdminServiceUpdateWorkspaceProcedure = "/tars.admin.v1.AdminService/UpdateWorkspace"
	// AdminServiceSetWorkspaceURLProcedure is the fully-qualified name of the AdminService's
	// SetWorkspaceURL RPC.
	AdminServiceSetWorkspaceURLProcedure = "/tars.admin.v1.AdminService/SetWorkspaceURL"
	// AdminServiceSetWorkspaceProjectProcedure is the fully-qualified name of the AdminService's
	// SetWorkspaceProject RPC.
	AdminServiceSetWorkspaceProjectProcedure = "/tars.admin.v1.AdminService/SetWorkspaceProject"
	// AdminServiceDeleteWorkspaceProcedure is the fully-qualified name of the AdminService's
	// DeleteWorkspace RPC.
	AdminServiceDeleteWorkspaceProcedure = "/tars.admin.v1.AdminService/DeleteWorkspace"
	// AdminServiceCreateServiceAccountProcedure is the fully-qualified name of the AdminService's
	// CreateServiceAccount RPC.
	AdminServiceCreateServiceAccountProcedure = "/tars.admin.v1.AdminService/CreateServiceAccount"
	// AdminServiceListServiceAccountsProcedure is the fully-qualified name of the AdminService's
	// ListServiceAccounts RPC.
	AdminServiceListServiceAccountsProcedure = "/tars.admin.v1.AdminService/ListServiceAccounts"
	// AdminServiceGetServiceAccountProcedure is the fully-qualified name of the AdminService's
	// GetServiceAccount RPC.
	AdminServiceGetServiceAccountProcedure = "/tars.admin.v1.AdminService/GetServiceAccount"
	// AdminServiceRevokeServiceAccountProcedure is the fully-qualified name of the AdminService's
	// RevokeServiceAccount RPC.
	AdminServiceRevokeServiceAccountProcedure = "/tars.admin.v1.AdminService/RevokeServiceAccount"
	// AdminServiceRestoreServiceAccountProcedure is the fully-qualified name of the AdminService's
	// RestoreServiceAccount RPC.
	AdminServiceRestoreServiceAccountProcedure = "/tars.admin.v1.AdminService/RestoreServiceAccount"
	// AdminServiceCreateUserTokenProcedure is the fully-qualified name of the AdminService's
	// CreateUserToken RPC.
	AdminServiceCreateUserTokenProcedure = "/tars.admin.v1.AdminService/CreateUserToken"
	// AdminServiceListUserTokensProcedure is the fully-qualified name of the AdminService's
	// ListUserTokens RPC.
	AdminServiceListUserTokensProcedure = "/tars.admin.v1.AdminService/ListUserTokens"
	// AdminServiceGetUserTokenProcedure is the fully-qualified name of the AdminService's GetUserToken
	// RPC.
	AdminServiceGetUserTokenProcedure = "/tars.admin.v1.AdminService/GetUserToken"
	// AdminServiceRevokeUserTokenProcedure is the fully-qualified name of the AdminService's
	// RevokeUserToken RPC.
	AdminServiceRevokeUserTokenProcedure = "/tars.admin.v1.AdminService/RevokeUserToken"
	// AdminServiceCreateTelemetryConfigProcedure is the fully-qualified name of the AdminService's
	// CreateTelemetryConfig RPC.
	AdminServiceCreateTelemetryConfigProcedure = "/tars.admin.v1.AdminService/CreateTelemetryConfig"
	// AdminServiceListTelemetryConfigsProcedure is the fully-qualified name of the AdminService's
	// ListTelemetryConfigs RPC.
	AdminServiceListTelemetryConfigsProcedure = "/tars.admin.v1.AdminService/ListTelemetryConfigs"
	// AdminServiceGetTelemetryConfigProcedure is the fully-qualified name of the AdminService's
	// GetTelemetryConfig RPC.
	AdminServiceGetTelemetryConfigProcedure = "/tars.admin.v1.AdminService/GetTelemetryConfig"
	// AdminServiceUpdateTelemetryConfigProcedure is the fully-qualified name of the AdminService's
	// UpdateTelemetryConfig RPC.
	AdminServiceUpdateTelemetryConfigProcedure = "/tars.admin.v1.AdminService/UpdateTelemetryConfig"
	// AdminServiceDeleteTelemetryConfigProcedure is the fully-qualified name of the AdminService's
	// DeleteTelemetryConfig RPC.
	AdminServiceDeleteTelemetryConfigProcedure = "/tars.admin.v1.AdminService/DeleteTelemetryConfig"
	// AdminServiceCreateCustomerProcedure is the fully-qualified name of the AdminService's
	// CreateCustomer RPC.
	AdminServiceCreateCustomerProcedure = "/tars.admin.v1.AdminService/CreateCustomer"
	// AdminServiceListCustomersProcedure is the fully-qualified name of the AdminService's
	// ListCustomers RPC.
	AdminServiceListCustomersProcedure = "/tars.admin.v1.AdminService/ListCustomers"
	// AdminServiceGetCustomerProcedure is the fully-qualified name of the AdminService's GetCustomer
	// RPC.
	AdminServiceGetCustomerProcedure = "/tars.admin.v1.AdminService/GetCustomer"
	// AdminServiceUpdateCustomerProcedure is the fully-qualified name of the AdminService's
	// UpdateCustomer RPC.
	AdminServiceUpdateCustomerProcedure = "/tars.admin.v1.AdminService/UpdateCustomer"
	// AdminServiceDeleteCustomerProcedure is the fully-qualified name of the AdminService's
	// DeleteCustomer RPC.
	AdminServiceDeleteCustomerProcedure = "/tars.admin.v1.AdminService/DeleteCustomer"
	// AdminServiceCreateProjectProcedure is the fully-qualified name of the AdminService's
	// CreateProject RPC.
	AdminServiceCreateProjectProcedure = "/tars.admin.v1.AdminService/CreateProject"
	// AdminServiceListProjectsProcedure is the fully-qualified name of the AdminService's ListProjects
	// RPC.
	AdminServiceListProjectsProcedure = "/tars.admin.v1.AdminService/ListProjects"
	// AdminServiceGetProjectProcedure is the fully-qualified name of the AdminService's GetProject RPC.
	AdminServiceGetProjectProcedure = "/tars.admin.v1.AdminService/GetProject"
	// AdminServiceUpdateProjectProcedure is the fully-qualified name of the AdminService's
	// UpdateProject RPC.
	AdminServiceUpdateProjectProcedure = "/tars.admin.v1.AdminService/UpdateProject"
	// AdminServiceDeleteProjectProcedure is the fully-qualified name of the AdminService's
	// DeleteProject RPC.
	AdminServiceDeleteProjectProcedure = "/tars.admin.v1.AdminService/DeleteProject"
	// AdminServiceAddProjectMemberProcedure is the fully-qualified name of the AdminService's
	// AddProjectMember RPC.
	AdminServiceAddProjectMemberProcedure = "/tars.admin.v1.AdminService/AddProjectMember"
	// AdminServiceListProjectMembersProcedure is the fully-qualified name of the AdminService's
	// ListProjectMembers RPC.
	AdminServiceListProjectMembersProcedure = "/tars.admin.v1.AdminService/ListProjectMembers"
	// AdminServiceUpdateProjectMemberProcedure is the fully-qualified name of the AdminService's
	// UpdateProjectMember RPC.
	AdminServiceUpdateProjectMemberProcedure = "/tars.admin.v1.AdminService/UpdateProjectMember"
	// AdminServiceRemoveProjectMemberProcedure is the fully-qualified name of the AdminService's
	// RemoveProjectMember RPC.
	AdminServiceRemoveProjectMemberProcedure = "/tars.admin.v1.AdminService/RemoveProjectMember"
	// AdminServiceListModelsProcedure is the fully-qualified name of the AdminService's ListModels RPC.
	AdminServiceListModelsProcedure = "/tars.admin.v1.AdminService/ListModels"
	// AdminServiceGetModelProcedure is the fully-qualified name of the AdminService's GetModel RPC.
	AdminServiceGetModelProcedure = "/tars.admin.v1.AdminService/GetModel"
	// AdminServiceAddProjectModelProcedure is the fully-qualified name of the AdminService's
	// AddProjectModel RPC.
	AdminServiceAddProjectModelProcedure = "/tars.admin.v1.AdminService/AddProjectModel"
	// AdminServiceListProjectModelsProcedure is the fully-qualified name of the AdminService's
	// ListProjectModels RPC.
	AdminServiceListProjectModelsProcedure = "/tars.admin.v1.AdminService/ListProjectModels"
	// AdminServiceRemoveProjectModelProcedure is the fully-qualified name of the AdminService's
	// RemoveProjectModel RPC.
	AdminServiceRemoveProjectModelProcedure = "/tars.admin.v1.AdminService/RemoveProjectModel"
	// AdminServiceAddProjectProviderProcedure is the fully-qualified name of the AdminService's
	// AddProjectProvider RPC.
	AdminServiceAddProjectProviderProcedure = "/tars.admin.v1.AdminService/AddProjectProvider"
	// AdminServiceListProjectProvidersProcedure is the fully-qualified name of the AdminService's
	// ListProjectProviders RPC.
	AdminServiceListProjectProvidersProcedure = "/tars.admin.v1.AdminService/ListProjectProviders"
	// AdminServiceRemoveProjectProviderProcedure is the fully-qualified name of the AdminService's
	// RemoveProjectProvider RPC.
	AdminServiceRemoveProjectProviderProcedure = "/tars.admin.v1.AdminService/RemoveProjectProvider"
	// AdminServiceAddProjectMcpServerProcedure is the fully-qualified name of the AdminService's
	// AddProjectMcpServer RPC.
	AdminServiceAddProjectMcpServerProcedure = "/tars.admin.v1.AdminService/AddProjectMcpServer"
	// AdminServiceListProjectMcpServersProcedure is the fully-qualified name of the AdminService's
	// ListProjectMcpServers RPC.
	AdminServiceListProjectMcpServersProcedure = "/tars.admin.v1.AdminService/ListProjectMcpServers"
	// AdminServiceRemoveProjectMcpServerProcedure is the fully-qualified name of the AdminService's
	// RemoveProjectMcpServer RPC.
	AdminServiceRemoveProjectMcpServerProcedure = "/tars.admin.v1.AdminService/RemoveProjectMcpServer"
	// AdminServiceGetProjectSettingsProcedure is the fully-qualified name of the AdminService's
	// GetProjectSettings RPC.
	AdminServiceGetProjectSettingsProcedure = "/tars.admin.v1.AdminService/GetProjectSettings"
	// AdminServiceUpsertProjectSettingProcedure is the fully-qualified name of the AdminService's
	// UpsertProjectSetting RPC.
	AdminServiceUpsertProjectSettingProcedure = "/tars.admin.v1.AdminService/UpsertProjectSetting"
	// AdminServiceDeleteProjectSettingProcedure is the fully-qualified name of the AdminService's
	// DeleteProjectSetting RPC.
	AdminServiceDeleteProjectSettingProcedure = "/tars.admin.v1.AdminService/DeleteProjectSetting"
)

// AdminServiceClient is a client for the tars.admin.v1.AdminService service.
type AdminServiceClient interface {
	// Ping endpoint for health checks and authentication testing
	Ping(context.Context, *connect.Request[v1.PingRequest]) (*connect.Response[v1.PingResponse], error)
	// Create workspace
	CreateWorkspace(context.Context, *connect.Request[v1.CreateWorkspaceRequest]) (*connect.Response[v1.CreateWorkspaceResponse], error)
	// List workspaces
	ListWorkspaces(context.Context, *connect.Request[v1.ListWorkspacesRequest]) (*connect.Response[v1.ListWorkspacesResponse], error)
	// Get workspace
	GetWorkspace(context.Context, *connect.Request[v1.GetWorkspaceRequest]) (*connect.Response[v1.GetWorkspaceResponse], error)
	// Update workspace
	UpdateWorkspace(context.Context, *connect.Request[v1.UpdateWorkspaceRequest]) (*connect.Response[v1.UpdateWorkspaceResponse], error)
	// Set the customer-facing gateway URL for a workspace data plane.
	// Writes system_settings.dataplane-url:<workspace_id> and optionally fires a PROXY_URL config event.
	SetWorkspaceURL(context.Context, *connect.Request[v1.SetWorkspaceURLRequest]) (*connect.Response[v1.SetWorkspaceURLResponse], error)
	// Assign workspace to a project (or clear back to default project by omitting project_id)
	SetWorkspaceProject(context.Context, *connect.Request[v1.SetWorkspaceProjectRequest]) (*connect.Response[v1.SetWorkspaceProjectResponse], error)
	// Delete workspace (soft delete)
	DeleteWorkspace(context.Context, *connect.Request[v1.DeleteWorkspaceRequest]) (*connect.Response[v1.DeleteWorkspaceResponse], error)
	// Create service account
	CreateServiceAccount(context.Context, *connect.Request[v1.CreateServiceAccountRequest]) (*connect.Response[v1.CreateServiceAccountResponse], error)
	// List service accounts
	ListServiceAccounts(context.Context, *connect.Request[v1.ListServiceAccountsRequest]) (*connect.Response[v1.ListServiceAccountsResponse], error)
	// Get service account
	GetServiceAccount(context.Context, *connect.Request[v1.GetServiceAccountRequest]) (*connect.Response[v1.GetServiceAccountResponse], error)
	// Revoke service account
	RevokeServiceAccount(context.Context, *connect.Request[v1.RevokeServiceAccountRequest]) (*connect.Response[v1.RevokeServiceAccountResponse], error)
	// Restore service account
	// Restores a revoked service account to active status.
	// Only one active service account per customer_id + workspace_id is allowed.
	RestoreServiceAccount(context.Context, *connect.Request[v1.RestoreServiceAccountRequest]) (*connect.Response[v1.RestoreServiceAccountResponse], error)
	// Create user token
	// Generates a JWT token for user authentication with gatekeeper.
	CreateUserToken(context.Context, *connect.Request[v1.CreateUserTokenRequest]) (*connect.Response[v1.CreateUserTokenResponse], error)
	// List user tokens
	ListUserTokens(context.Context, *connect.Request[v1.ListUserTokensRequest]) (*connect.Response[v1.ListUserTokensResponse], error)
	// Get user token
	GetUserToken(context.Context, *connect.Request[v1.GetUserTokenRequest]) (*connect.Response[v1.GetUserTokenResponse], error)
	// Revoke user token
	// Revokes a user token by its JTI (JWT ID).
	RevokeUserToken(context.Context, *connect.Request[v1.RevokeUserTokenRequest]) (*connect.Response[v1.RevokeUserTokenResponse], error)
	// Create telemetry config
	CreateTelemetryConfig(context.Context, *connect.Request[v1.CreateTelemetryConfigRequest]) (*connect.Response[v1.CreateTelemetryConfigResponse], error)
	// List telemetry configs
	ListTelemetryConfigs(context.Context, *connect.Request[v1.ListTelemetryConfigsRequest]) (*connect.Response[v1.ListTelemetryConfigsResponse], error)
	// Get telemetry config
	GetTelemetryConfig(context.Context, *connect.Request[v1.GetTelemetryConfigRequest]) (*connect.Response[v1.GetTelemetryConfigResponse], error)
	// Update telemetry config
	UpdateTelemetryConfig(context.Context, *connect.Request[v1.UpdateTelemetryConfigRequest]) (*connect.Response[v1.UpdateTelemetryConfigResponse], error)
	// Delete telemetry config
	DeleteTelemetryConfig(context.Context, *connect.Request[v1.DeleteTelemetryConfigRequest]) (*connect.Response[v1.DeleteTelemetryConfigResponse], error)
	CreateCustomer(context.Context, *connect.Request[v1.CreateCustomerRequest]) (*connect.Response[v1.CreateCustomerResponse], error)
	ListCustomers(context.Context, *connect.Request[v1.ListCustomersRequest]) (*connect.Response[v1.ListCustomersResponse], error)
	GetCustomer(context.Context, *connect.Request[v1.GetCustomerRequest]) (*connect.Response[v1.GetCustomerResponse], error)
	UpdateCustomer(context.Context, *connect.Request[v1.UpdateCustomerRequest]) (*connect.Response[v1.UpdateCustomerResponse], error)
	DeleteCustomer(context.Context, *connect.Request[v1.DeleteCustomerRequest]) (*connect.Response[v1.DeleteCustomerResponse], error)
	CreateProject(context.Context, *connect.Request[v1.CreateProjectRequest]) (*connect.Response[v1.CreateProjectResponse], error)
	ListProjects(context.Context, *connect.Request[v1.ListProjectsRequest]) (*connect.Response[v1.ListProjectsResponse], error)
	GetProject(context.Context, *connect.Request[v1.GetProjectRequest]) (*connect.Response[v1.GetProjectResponse], error)
	UpdateProject(context.Context, *connect.Request[v1.UpdateProjectRequest]) (*connect.Response[v1.UpdateProjectResponse], error)
	DeleteProject(context.Context, *connect.Request[v1.DeleteProjectRequest]) (*connect.Response[v1.DeleteProjectResponse], error)
	AddProjectMember(context.Context, *connect.Request[v1.AddProjectMemberRequest]) (*connect.Response[v1.AddProjectMemberResponse], error)
	ListProjectMembers(context.Context, *connect.Request[v1.ListProjectMembersRequest]) (*connect.Response[v1.ListProjectMembersResponse], error)
	UpdateProjectMember(context.Context, *connect.Request[v1.UpdateProjectMemberRequest]) (*connect.Response[v1.UpdateProjectMemberResponse], error)
	RemoveProjectMember(context.Context, *connect.Request[v1.RemoveProjectMemberRequest]) (*connect.Response[v1.RemoveProjectMemberResponse], error)
	ListModels(context.Context, *connect.Request[v1.ListModelsRequest]) (*connect.Response[v1.ListModelsResponse], error)
	GetModel(context.Context, *connect.Request[v1.GetModelRequest]) (*connect.Response[v1.GetModelResponse], error)
	AddProjectModel(context.Context, *connect.Request[v1.AddProjectModelRequest]) (*connect.Response[v1.AddProjectModelResponse], error)
	ListProjectModels(context.Context, *connect.Request[v1.ListProjectModelsRequest]) (*connect.Response[v1.ListProjectModelsResponse], error)
	RemoveProjectModel(context.Context, *connect.Request[v1.RemoveProjectModelRequest]) (*connect.Response[v1.RemoveProjectModelResponse], error)
	AddProjectProvider(context.Context, *connect.Request[v1.AddProjectProviderRequest]) (*connect.Response[v1.AddProjectProviderResponse], error)
	ListProjectProviders(context.Context, *connect.Request[v1.ListProjectProvidersRequest]) (*connect.Response[v1.ListProjectProvidersResponse], error)
	RemoveProjectProvider(context.Context, *connect.Request[v1.RemoveProjectProviderRequest]) (*connect.Response[v1.RemoveProjectProviderResponse], error)
	AddProjectMcpServer(context.Context, *connect.Request[v1.AddProjectMcpServerRequest]) (*connect.Response[v1.AddProjectMcpServerResponse], error)
	ListProjectMcpServers(context.Context, *connect.Request[v1.ListProjectMcpServersRequest]) (*connect.Response[v1.ListProjectMcpServersResponse], error)
	RemoveProjectMcpServer(context.Context, *connect.Request[v1.RemoveProjectMcpServerRequest]) (*connect.Response[v1.RemoveProjectMcpServerResponse], error)
	GetProjectSettings(context.Context, *connect.Request[v1.GetProjectSettingsRequest]) (*connect.Response[v1.GetProjectSettingsResponse], error)
	UpsertProjectSetting(context.Context, *connect.Request[v1.UpsertProjectSettingRequest]) (*connect.Response[v1.UpsertProjectSettingResponse], error)
	DeleteProjectSetting(context.Context, *connect.Request[v1.DeleteProjectSettingRequest]) (*connect.Response[v1.DeleteProjectSettingResponse], error)
}

// NewAdminServiceClient constructs a client for the tars.admin.v1.AdminService service. By default,
// it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and
// sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC()
// or connect.WithGRPCWeb() options.
//
// The URL supplied here should be the base URL for the Connect or gRPC server (for example,
// http://api.acme.com or https://acme.com/grpc).
func NewAdminServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) AdminServiceClient {
	baseURL = strings.TrimRight(baseURL, "/")
	adminServiceMethods := v1.File_tars_admin_v1_admin_proto.Services().ByName("AdminService").Methods()
	return &adminServiceClient{
		ping: connect.NewClient[v1.PingRequest, v1.PingResponse](
			httpClient,
			baseURL+AdminServicePingProcedure,
			connect.WithSchema(adminServiceMethods.ByName("Ping")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		createWorkspace: connect.NewClient[v1.CreateWorkspaceRequest, v1.CreateWorkspaceResponse](
			httpClient,
			baseURL+AdminServiceCreateWorkspaceProcedure,
			connect.WithSchema(adminServiceMethods.ByName("CreateWorkspace")),
			connect.WithClientOptions(opts...),
		),
		listWorkspaces: connect.NewClient[v1.ListWorkspacesRequest, v1.ListWorkspacesResponse](
			httpClient,
			baseURL+AdminServiceListWorkspacesProcedure,
			connect.WithSchema(adminServiceMethods.ByName("ListWorkspaces")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		getWorkspace: connect.NewClient[v1.GetWorkspaceRequest, v1.GetWorkspaceResponse](
			httpClient,
			baseURL+AdminServiceGetWorkspaceProcedure,
			connect.WithSchema(adminServiceMethods.ByName("GetWorkspace")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		updateWorkspace: connect.NewClient[v1.UpdateWorkspaceRequest, v1.UpdateWorkspaceResponse](
			httpClient,
			baseURL+AdminServiceUpdateWorkspaceProcedure,
			connect.WithSchema(adminServiceMethods.ByName("UpdateWorkspace")),
			connect.WithClientOptions(opts...),
		),
		setWorkspaceURL: connect.NewClient[v1.SetWorkspaceURLRequest, v1.SetWorkspaceURLResponse](
			httpClient,
			baseURL+AdminServiceSetWorkspaceURLProcedure,
			connect.WithSchema(adminServiceMethods.ByName("SetWorkspaceURL")),
			connect.WithClientOptions(opts...),
		),
		setWorkspaceProject: connect.NewClient[v1.SetWorkspaceProjectRequest, v1.SetWorkspaceProjectResponse](
			httpClient,
			baseURL+AdminServiceSetWorkspaceProjectProcedure,
			connect.WithSchema(adminServiceMethods.ByName("SetWorkspaceProject")),
			connect.WithClientOptions(opts...),
		),
		deleteWorkspace: connect.NewClient[v1.DeleteWorkspaceRequest, v1.DeleteWorkspaceResponse](
			httpClient,
			baseURL+AdminServiceDeleteWorkspaceProcedure,
			connect.WithSchema(adminServiceMethods.ByName("DeleteWorkspace")),
			connect.WithClientOptions(opts...),
		),
		createServiceAccount: connect.NewClient[v1.CreateServiceAccountRequest, v1.CreateServiceAccountResponse](
			httpClient,
			baseURL+AdminServiceCreateServiceAccountProcedure,
			connect.WithSchema(adminServiceMethods.ByName("CreateServiceAccount")),
			connect.WithClientOptions(opts...),
		),
		listServiceAccounts: connect.NewClient[v1.ListServiceAccountsRequest, v1.ListServiceAccountsResponse](
			httpClient,
			baseURL+AdminServiceListServiceAccountsProcedure,
			connect.WithSchema(adminServiceMethods.ByName("ListServiceAccounts")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		getServiceAccount: connect.NewClient[v1.GetServiceAccountRequest, v1.GetServiceAccountResponse](
			httpClient,
			baseURL+AdminServiceGetServiceAccountProcedure,
			connect.WithSchema(adminServiceMethods.ByName("GetServiceAccount")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		revokeServiceAccount: connect.NewClient[v1.RevokeServiceAccountRequest, v1.RevokeServiceAccountResponse](
			httpClient,
			baseURL+AdminServiceRevokeServiceAccountProcedure,
			connect.WithSchema(adminServiceMethods.ByName("RevokeServiceAccount")),
			connect.WithClientOptions(opts...),
		),
		restoreServiceAccount: connect.NewClient[v1.RestoreServiceAccountRequest, v1.RestoreServiceAccountResponse](
			httpClient,
			baseURL+AdminServiceRestoreServiceAccountProcedure,
			connect.WithSchema(adminServiceMethods.ByName("RestoreServiceAccount")),
			connect.WithClientOptions(opts...),
		),
		createUserToken: connect.NewClient[v1.CreateUserTokenRequest, v1.CreateUserTokenResponse](
			httpClient,
			baseURL+AdminServiceCreateUserTokenProcedure,
			connect.WithSchema(adminServiceMethods.ByName("CreateUserToken")),
			connect.WithClientOptions(opts...),
		),
		listUserTokens: connect.NewClient[v1.ListUserTokensRequest, v1.ListUserTokensResponse](
			httpClient,
			baseURL+AdminServiceListUserTokensProcedure,
			connect.WithSchema(adminServiceMethods.ByName("ListUserTokens")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		getUserToken: connect.NewClient[v1.GetUserTokenRequest, v1.GetUserTokenResponse](
			httpClient,
			baseURL+AdminServiceGetUserTokenProcedure,
			connect.WithSchema(adminServiceMethods.ByName("GetUserToken")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		revokeUserToken: connect.NewClient[v1.RevokeUserTokenRequest, v1.RevokeUserTokenResponse](
			httpClient,
			baseURL+AdminServiceRevokeUserTokenProcedure,
			connect.WithSchema(adminServiceMethods.ByName("RevokeUserToken")),
			connect.WithClientOptions(opts...),
		),
		createTelemetryConfig: connect.NewClient[v1.CreateTelemetryConfigRequest, v1.CreateTelemetryConfigResponse](
			httpClient,
			baseURL+AdminServiceCreateTelemetryConfigProcedure,
			connect.WithSchema(adminServiceMethods.ByName("CreateTelemetryConfig")),
			connect.WithClientOptions(opts...),
		),
		listTelemetryConfigs: connect.NewClient[v1.ListTelemetryConfigsRequest, v1.ListTelemetryConfigsResponse](
			httpClient,
			baseURL+AdminServiceListTelemetryConfigsProcedure,
			connect.WithSchema(adminServiceMethods.ByName("ListTelemetryConfigs")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		getTelemetryConfig: connect.NewClient[v1.GetTelemetryConfigRequest, v1.GetTelemetryConfigResponse](
			httpClient,
			baseURL+AdminServiceGetTelemetryConfigProcedure,
			connect.WithSchema(adminServiceMethods.ByName("GetTelemetryConfig")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		updateTelemetryConfig: connect.NewClient[v1.UpdateTelemetryConfigRequest, v1.UpdateTelemetryConfigResponse](
			httpClient,
			baseURL+AdminServiceUpdateTelemetryConfigProcedure,
			connect.WithSchema(adminServiceMethods.ByName("UpdateTelemetryConfig")),
			connect.WithClientOptions(opts...),
		),
		deleteTelemetryConfig: connect.NewClient[v1.DeleteTelemetryConfigRequest, v1.DeleteTelemetryConfigResponse](
			httpClient,
			baseURL+AdminServiceDeleteTelemetryConfigProcedure,
			connect.WithSchema(adminServiceMethods.ByName("DeleteTelemetryConfig")),
			connect.WithClientOptions(opts...),
		),
		createCustomer: connect.NewClient[v1.CreateCustomerRequest, v1.CreateCustomerResponse](
			httpClient,
			baseURL+AdminServiceCreateCustomerProcedure,
			connect.WithSchema(adminServiceMethods.ByName("CreateCustomer")),
			connect.WithClientOptions(opts...),
		),
		listCustomers: connect.NewClient[v1.ListCustomersRequest, v1.ListCustomersResponse](
			httpClient,
			baseURL+AdminServiceListCustomersProcedure,
			connect.WithSchema(adminServiceMethods.ByName("ListCustomers")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		getCustomer: connect.NewClient[v1.GetCustomerRequest, v1.GetCustomerResponse](
			httpClient,
			baseURL+AdminServiceGetCustomerProcedure,
			connect.WithSchema(adminServiceMethods.ByName("GetCustomer")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		updateCustomer: connect.NewClient[v1.UpdateCustomerRequest, v1.UpdateCustomerResponse](
			httpClient,
			baseURL+AdminServiceUpdateCustomerProcedure,
			connect.WithSchema(adminServiceMethods.ByName("UpdateCustomer")),
			connect.WithClientOptions(opts...),
		),
		deleteCustomer: connect.NewClient[v1.DeleteCustomerRequest, v1.DeleteCustomerResponse](
			httpClient,
			baseURL+AdminServiceDeleteCustomerProcedure,
			connect.WithSchema(adminServiceMethods.ByName("DeleteCustomer")),
			connect.WithClientOptions(opts...),
		),
		createProject: connect.NewClient[v1.CreateProjectRequest, v1.CreateProjectResponse](
			httpClient,
			baseURL+AdminServiceCreateProjectProcedure,
			connect.WithSchema(adminServiceMethods.ByName("CreateProject")),
			connect.WithClientOptions(opts...),
		),
		listProjects: connect.NewClient[v1.ListProjectsRequest, v1.ListProjectsResponse](
			httpClient,
			baseURL+AdminServiceListProjectsProcedure,
			connect.WithSchema(adminServiceMethods.ByName("ListProjects")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		getProject: connect.NewClient[v1.GetProjectRequest, v1.GetProjectResponse](
			httpClient,
			baseURL+AdminServiceGetProjectProcedure,
			connect.WithSchema(adminServiceMethods.ByName("GetProject")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		updateProject: connect.NewClient[v1.UpdateProjectRequest, v1.UpdateProjectResponse](
			httpClient,
			baseURL+AdminServiceUpdateProjectProcedure,
			connect.WithSchema(adminServiceMethods.ByName("UpdateProject")),
			connect.WithClientOptions(opts...),
		),
		deleteProject: connect.NewClient[v1.DeleteProjectRequest, v1.DeleteProjectResponse](
			httpClient,
			baseURL+AdminServiceDeleteProjectProcedure,
			connect.WithSchema(adminServiceMethods.ByName("DeleteProject")),
			connect.WithClientOptions(opts...),
		),
		addProjectMember: connect.NewClient[v1.AddProjectMemberRequest, v1.AddProjectMemberResponse](
			httpClient,
			baseURL+AdminServiceAddProjectMemberProcedure,
			connect.WithSchema(adminServiceMethods.ByName("AddProjectMember")),
			connect.WithClientOptions(opts...),
		),
		listProjectMembers: connect.NewClient[v1.ListProjectMembersRequest, v1.ListProjectMembersResponse](
			httpClient,
			baseURL+AdminServiceListProjectMembersProcedure,
			connect.WithSchema(adminServiceMethods.ByName("ListProjectMembers")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		updateProjectMember: connect.NewClient[v1.UpdateProjectMemberRequest, v1.UpdateProjectMemberResponse](
			httpClient,
			baseURL+AdminServiceUpdateProjectMemberProcedure,
			connect.WithSchema(adminServiceMethods.ByName("UpdateProjectMember")),
			connect.WithClientOptions(opts...),
		),
		removeProjectMember: connect.NewClient[v1.RemoveProjectMemberRequest, v1.RemoveProjectMemberResponse](
			httpClient,
			baseURL+AdminServiceRemoveProjectMemberProcedure,
			connect.WithSchema(adminServiceMethods.ByName("RemoveProjectMember")),
			connect.WithClientOptions(opts...),
		),
		listModels: connect.NewClient[v1.ListModelsRequest, v1.ListModelsResponse](
			httpClient,
			baseURL+AdminServiceListModelsProcedure,
			connect.WithSchema(adminServiceMethods.ByName("ListModels")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		getModel: connect.NewClient[v1.GetModelRequest, v1.GetModelResponse](
			httpClient,
			baseURL+AdminServiceGetModelProcedure,
			connect.WithSchema(adminServiceMethods.ByName("GetModel")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		addProjectModel: connect.NewClient[v1.AddProjectModelRequest, v1.AddProjectModelResponse](
			httpClient,
			baseURL+AdminServiceAddProjectModelProcedure,
			connect.WithSchema(adminServiceMethods.ByName("AddProjectModel")),
			connect.WithClientOptions(opts...),
		),
		listProjectModels: connect.NewClient[v1.ListProjectModelsRequest, v1.ListProjectModelsResponse](
			httpClient,
			baseURL+AdminServiceListProjectModelsProcedure,
			connect.WithSchema(adminServiceMethods.ByName("ListProjectModels")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		removeProjectModel: connect.NewClient[v1.RemoveProjectModelRequest, v1.RemoveProjectModelResponse](
			httpClient,
			baseURL+AdminServiceRemoveProjectModelProcedure,
			connect.WithSchema(adminServiceMethods.ByName("RemoveProjectModel")),
			connect.WithClientOptions(opts...),
		),
		addProjectProvider: connect.NewClient[v1.AddProjectProviderRequest, v1.AddProjectProviderResponse](
			httpClient,
			baseURL+AdminServiceAddProjectProviderProcedure,
			connect.WithSchema(adminServiceMethods.ByName("AddProjectProvider")),
			connect.WithClientOptions(opts...),
		),
		listProjectProviders: connect.NewClient[v1.ListProjectProvidersRequest, v1.ListProjectProvidersResponse](
			httpClient,
			baseURL+AdminServiceListProjectProvidersProcedure,
			connect.WithSchema(adminServiceMethods.ByName("ListProjectProviders")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		removeProjectProvider: connect.NewClient[v1.RemoveProjectProviderRequest, v1.RemoveProjectProviderResponse](
			httpClient,
			baseURL+AdminServiceRemoveProjectProviderProcedure,
			connect.WithSchema(adminServiceMethods.ByName("RemoveProjectProvider")),
			connect.WithClientOptions(opts...),
		),
		addProjectMcpServer: connect.NewClient[v1.AddProjectMcpServerRequest, v1.AddProjectMcpServerResponse](
			httpClient,
			baseURL+AdminServiceAddProjectMcpServerProcedure,
			connect.WithSchema(adminServiceMethods.ByName("AddProjectMcpServer")),
			connect.WithClientOptions(opts...),
		),
		listProjectMcpServers: connect.NewClient[v1.ListProjectMcpServersRequest, v1.ListProjectMcpServersResponse](
			httpClient,
			baseURL+AdminServiceListProjectMcpServersProcedure,
			connect.WithSchema(adminServiceMethods.ByName("ListProjectMcpServers")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		removeProjectMcpServer: connect.NewClient[v1.RemoveProjectMcpServerRequest, v1.RemoveProjectMcpServerResponse](
			httpClient,
			baseURL+AdminServiceRemoveProjectMcpServerProcedure,
			connect.WithSchema(adminServiceMethods.ByName("RemoveProjectMcpServer")),
			connect.WithClientOptions(opts...),
		),
		getProjectSettings: connect.NewClient[v1.GetProjectSettingsRequest, v1.GetProjectSettingsResponse](
			httpClient,
			baseURL+AdminServiceGetProjectSettingsProcedure,
			connect.WithSchema(adminServiceMethods.ByName("GetProjectSettings")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
		upsertProjectSetting: connect.NewClient[v1.UpsertProjectSettingRequest, v1.UpsertProjectSettingResponse](
			httpClient,
			baseURL+AdminServiceUpsertProjectSettingProcedure,
			connect.WithSchema(adminServiceMethods.ByName("UpsertProjectSetting")),
			connect.WithClientOptions(opts...),
		),
		deleteProjectSetting: connect.NewClient[v1.DeleteProjectSettingRequest, v1.DeleteProjectSettingResponse](
			httpClient,
			baseURL+AdminServiceDeleteProjectSettingProcedure,
			connect.WithSchema(adminServiceMethods.ByName("DeleteProjectSetting")),
			connect.WithClientOptions(opts...),
		),
	}
}

// adminServiceClient implements AdminServiceClient.
type adminServiceClient struct {
	ping                   *connect.Client[v1.PingRequest, v1.PingResponse]
	createWorkspace        *connect.Client[v1.CreateWorkspaceRequest, v1.CreateWorkspaceResponse]
	listWorkspaces         *connect.Client[v1.ListWorkspacesRequest, v1.ListWorkspacesResponse]
	getWorkspace           *connect.Client[v1.GetWorkspaceRequest, v1.GetWorkspaceResponse]
	updateWorkspace        *connect.Client[v1.UpdateWorkspaceRequest, v1.UpdateWorkspaceResponse]
	setWorkspaceURL        *connect.Client[v1.SetWorkspaceURLRequest, v1.SetWorkspaceURLResponse]
	setWorkspaceProject    *connect.Client[v1.SetWorkspaceProjectRequest, v1.SetWorkspaceProjectResponse]
	deleteWorkspace        *connect.Client[v1.DeleteWorkspaceRequest, v1.DeleteWorkspaceResponse]
	createServiceAccount   *connect.Client[v1.CreateServiceAccountRequest, v1.CreateServiceAccountResponse]
	listServiceAccounts    *connect.Client[v1.ListServiceAccountsRequest, v1.ListServiceAccountsResponse]
	getServiceAccount      *connect.Client[v1.GetServiceAccountRequest, v1.GetServiceAccountResponse]
	revokeServiceAccount   *connect.Client[v1.RevokeServiceAccountRequest, v1.RevokeServiceAccountResponse]
	restoreServiceAccount  *connect.Client[v1.RestoreServiceAccountRequest, v1.RestoreServiceAccountResponse]
	createUserToken        *connect.Client[v1.CreateUserTokenRequest, v1.CreateUserTokenResponse]
	listUserTokens         *connect.Client[v1.ListUserTokensRequest, v1.ListUserTokensResponse]
	getUserToken           *connect.Client[v1.GetUserTokenRequest, v1.GetUserTokenResponse]
	revokeUserToken        *connect.Client[v1.RevokeUserTokenRequest, v1.RevokeUserTokenResponse]
	createTelemetryConfig  *connect.Client[v1.CreateTelemetryConfigRequest, v1.CreateTelemetryConfigResponse]
	listTelemetryConfigs   *connect.Client[v1.ListTelemetryConfigsRequest, v1.ListTelemetryConfigsResponse]
	getTelemetryConfig     *connect.Client[v1.GetTelemetryConfigRequest, v1.GetTelemetryConfigResponse]
	updateTelemetryConfig  *connect.Client[v1.UpdateTelemetryConfigRequest, v1.UpdateTelemetryConfigResponse]
	deleteTelemetryConfig  *connect.Client[v1.DeleteTelemetryConfigRequest, v1.DeleteTelemetryConfigResponse]
	createCustomer         *connect.Client[v1.CreateCustomerRequest, v1.CreateCustomerResponse]
	listCustomers          *connect.Client[v1.ListCustomersRequest, v1.ListCustomersResponse]
	getCustomer            *connect.Client[v1.GetCustomerRequest, v1.GetCustomerResponse]
	updateCustomer         *connect.Client[v1.UpdateCustomerRequest, v1.UpdateCustomerResponse]
	deleteCustomer         *connect.Client[v1.DeleteCustomerRequest, v1.DeleteCustomerResponse]
	createProject          *connect.Client[v1.CreateProjectRequest, v1.CreateProjectResponse]
	listProjects           *connect.Client[v1.ListProjectsRequest, v1.ListProjectsResponse]
	getProject             *connect.Client[v1.GetProjectRequest, v1.GetProjectResponse]
	updateProject          *connect.Client[v1.UpdateProjectRequest, v1.UpdateProjectResponse]
	deleteProject          *connect.Client[v1.DeleteProjectRequest, v1.DeleteProjectResponse]
	addProjectMember       *connect.Client[v1.AddProjectMemberRequest, v1.AddProjectMemberResponse]
	listProjectMembers     *connect.Client[v1.ListProjectMembersRequest, v1.ListProjectMembersResponse]
	updateProjectMember    *connect.Client[v1.UpdateProjectMemberRequest, v1.UpdateProjectMemberResponse]
	removeProjectMember    *connect.Client[v1.RemoveProjectMemberRequest, v1.RemoveProjectMemberResponse]
	listModels             *connect.Client[v1.ListModelsRequest, v1.ListModelsResponse]
	getModel               *connect.Client[v1.GetModelRequest, v1.GetModelResponse]
	addProjectModel        *connect.Client[v1.AddProjectModelRequest, v1.AddProjectModelResponse]
	listProjectModels      *connect.Client[v1.ListProjectModelsRequest, v1.ListProjectModelsResponse]
	removeProjectModel     *connect.Client[v1.RemoveProjectModelRequest, v1.RemoveProjectModelResponse]
	addProjectProvider     *connect.Client[v1.AddProjectProviderRequest, v1.AddProjectProviderResponse]
	listProjectProviders   *connect.Client[v1.ListProjectProvidersRequest, v1.ListProjectProvidersResponse]
	removeProjectProvider  *connect.Client[v1.RemoveProjectProviderRequest, v1.RemoveProjectProviderResponse]
	addProjectMcpServer    *connect.Client[v1.AddProjectMcpServerRequest, v1.AddProjectMcpServerResponse]
	listProjectMcpServers  *connect.Client[v1.ListProjectMcpServersRequest, v1.ListProjectMcpServersResponse]
	removeProjectMcpServer *connect.Client[v1.RemoveProjectMcpServerRequest, v1.RemoveProjectMcpServerResponse]
	getProjectSettings     *connect.Client[v1.GetProjectSettingsRequest, v1.GetProjectSettingsResponse]
	upsertProjectSetting   *connect.Client[v1.UpsertProjectSettingRequest, v1.UpsertProjectSettingResponse]
	deleteProjectSetting   *connect.Client[v1.DeleteProjectSettingRequest, v1.DeleteProjectSettingResponse]
}

// Ping calls tars.admin.v1.AdminService.Ping.
func (c *adminServiceClient) Ping(ctx context.Context, req *connect.Request[v1.PingRequest]) (*connect.Response[v1.PingResponse], error) {
	return c.ping.CallUnary(ctx, req)
}

// CreateWorkspace calls tars.admin.v1.AdminService.CreateWorkspace.
func (c *adminServiceClient) CreateWorkspace(ctx context.Context, req *connect.Request[v1.CreateWorkspaceRequest]) (*connect.Response[v1.CreateWorkspaceResponse], error) {
	return c.createWorkspace.CallUnary(ctx, req)
}

// ListWorkspaces calls tars.admin.v1.AdminService.ListWorkspaces.
func (c *adminServiceClient) ListWorkspaces(ctx context.Context, req *connect.Request[v1.ListWorkspacesRequest]) (*connect.Response[v1.ListWorkspacesResponse], error) {
	return c.listWorkspaces.CallUnary(ctx, req)
}

// GetWorkspace calls tars.admin.v1.AdminService.GetWorkspace.
func (c *adminServiceClient) GetWorkspace(ctx context.Context, req *connect.Request[v1.GetWorkspaceRequest]) (*connect.Response[v1.GetWorkspaceResponse], error) {
	return c.getWorkspace.CallUnary(ctx, req)
}

// UpdateWorkspace calls tars.admin.v1.AdminService.UpdateWorkspace.
func (c *adminServiceClient) UpdateWorkspace(ctx context.Context, req *connect.Request[v1.UpdateWorkspaceRequest]) (*connect.Response[v1.UpdateWorkspaceResponse], error) {
	return c.updateWorkspace.CallUnary(ctx, req)
}

// SetWorkspaceURL calls tars.admin.v1.AdminService.SetWorkspaceURL.
func (c *adminServiceClient) SetWorkspaceURL(ctx context.Context, req *connect.Request[v1.SetWorkspaceURLRequest]) (*connect.Response[v1.SetWorkspaceURLResponse], error) {
	return c.setWorkspaceURL.CallUnary(ctx, req)
}

// SetWorkspaceProject calls tars.admin.v1.AdminService.SetWorkspaceProject.
func (c *adminServiceClient) SetWorkspaceProject(ctx context.Context, req *connect.Request[v1.SetWorkspaceProjectRequest]) (*connect.Response[v1.SetWorkspaceProjectResponse], error) {
	return c.setWorkspaceProject.CallUnary(ctx, req)
}

// DeleteWorkspace calls tars.admin.v1.AdminService.DeleteWorkspace.
func (c *adminServiceClient) DeleteWorkspace(ctx context.Context, req *connect.Request[v1.DeleteWorkspaceRequest]) (*connect.Response[v1.DeleteWorkspaceResponse], error) {
	return c.deleteWorkspace.CallUnary(ctx, req)
}

// CreateServiceAccount calls tars.admin.v1.AdminService.CreateServiceAccount.
func (c *adminServiceClient) CreateServiceAccount(ctx context.Context, req *connect.Request[v1.CreateServiceAccountRequest]) (*connect.Response[v1.CreateServiceAccountResponse], error) {
	return c.createServiceAccount.CallUnary(ctx, req)
}

// ListServiceAccounts calls tars.admin.v1.AdminService.ListServiceAccounts.
func (c *adminServiceClient) ListServiceAccounts(ctx context.Context, req *connect.Request[v1.ListServiceAccountsRequest]) (*connect.Response[v1.ListServiceAccountsResponse], error) {
	return c.listServiceAccounts.CallUnary(ctx, req)
}

// GetServiceAccount calls tars.admin.v1.AdminService.GetServiceAccount.
func (c *adminServiceClient) GetServiceAccount(ctx context.Context, req *connect.Request[v1.GetServiceAccountRequest]) (*connect.Response[v1.GetServiceAccountResponse], error) {
	return c.getServiceAccount.CallUnary(ctx, req)
}

// RevokeServiceAccount calls tars.admin.v1.AdminService.RevokeServiceAccount.
func (c *adminServiceClient) RevokeServiceAccount(ctx context.Context, req *connect.Request[v1.RevokeServiceAccountRequest]) (*connect.Response[v1.RevokeServiceAccountResponse], error) {
	return c.revokeServiceAccount.CallUnary(ctx, req)
}

// RestoreServiceAccount calls tars.admin.v1.AdminService.RestoreServiceAccount.
func (c *adminServiceClient) RestoreServiceAccount(ctx context.Context, req *connect.Request[v1.RestoreServiceAccountRequest]) (*connect.Response[v1.RestoreServiceAccountResponse], error) {
	return c.restoreServiceAccount.CallUnary(ctx, req)
}

// CreateUserToken calls tars.admin.v1.AdminService.CreateUserToken.
func (c *adminServiceClient) CreateUserToken(ctx context.Context, req *connect.Request[v1.CreateUserTokenRequest]) (*connect.Response[v1.CreateUserTokenResponse], error) {
	return c.createUserToken.CallUnary(ctx, req)
}

// ListUserTokens calls tars.admin.v1.AdminService.ListUserTokens.
func (c *adminServiceClient) ListUserTokens(ctx context.Context, req *connect.Request[v1.ListUserTokensRequest]) (*connect.Response[v1.ListUserTokensResponse], error) {
	return c.listUserTokens.CallUnary(ctx, req)
}

// GetUserToken calls tars.admin.v1.AdminService.GetUserToken.
func (c *adminServiceClient) GetUserToken(ctx context.Context, req *connect.Request[v1.GetUserTokenRequest]) (*connect.Response[v1.GetUserTokenResponse], error) {
	return c.getUserToken.CallUnary(ctx, req)
}

// RevokeUserToken calls tars.admin.v1.AdminService.RevokeUserToken.
func (c *adminServiceClient) RevokeUserToken(ctx context.Context, req *connect.Request[v1.RevokeUserTokenRequest]) (*connect.Response[v1.RevokeUserTokenResponse], error) {
	return c.revokeUserToken.CallUnary(ctx, req)
}

// CreateTelemetryConfig calls tars.admin.v1.AdminService.CreateTelemetryConfig.
func (c *adminServiceClient) CreateTelemetryConfig(ctx context.Context, req *connect.Request[v1.CreateTelemetryConfigRequest]) (*connect.Response[v1.CreateTelemetryConfigResponse], error) {
	return c.createTelemetryConfig.CallUnary(ctx, req)
}

// ListTelemetryConfigs calls tars.admin.v1.AdminService.ListTelemetryConfigs.
func (c *adminServiceClient) ListTelemetryConfigs(ctx context.Context, req *connect.Request[v1.ListTelemetryConfigsRequest]) (*connect.Response[v1.ListTelemetryConfigsResponse], error) {
	return c.listTelemetryConfigs.CallUnary(ctx, req)
}

// GetTelemetryConfig calls tars.admin.v1.AdminService.GetTelemetryConfig.
func (c *adminServiceClient) GetTelemetryConfig(ctx context.Context, req *connect.Request[v1.GetTelemetryConfigRequest]) (*connect.Response[v1.GetTelemetryConfigResponse], error) {
	return c.getTelemetryConfig.CallUnary(ctx, req)
}

// UpdateTelemetryConfig calls tars.admin.v1.AdminService.UpdateTelemetryConfig.
func (c *adminServiceClient) UpdateTelemetryConfig(ctx context.Context, req *connect.Request[v1.UpdateTelemetryConfigRequest]) (*connect.Response[v1.UpdateTelemetryConfigResponse], error) {
	return c.updateTelemetryConfig.CallUnary(ctx, req)
}

// DeleteTelemetryConfig calls tars.admin.v1.AdminService.DeleteTelemetryConfig.
func (c *adminServiceClient) DeleteTelemetryConfig(ctx context.Context, req *connect.Request[v1.DeleteTelemetryConfigRequest]) (*connect.Response[v1.DeleteTelemetryConfigResponse], error) {
	return c.deleteTelemetryConfig.CallUnary(ctx, req)
}

// CreateCustomer calls tars.admin.v1.AdminService.CreateCustomer.
func (c *adminServiceClient) CreateCustomer(ctx context.Context, req *connect.Request[v1.CreateCustomerRequest]) (*connect.Response[v1.CreateCustomerResponse], error) {
	return c.createCustomer.CallUnary(ctx, req)
}

// ListCustomers calls tars.admin.v1.AdminService.ListCustomers.
func (c *adminServiceClient) ListCustomers(ctx context.Context, req *connect.Request[v1.ListCustomersRequest]) (*connect.Response[v1.ListCustomersResponse], error) {
	return c.listCustomers.CallUnary(ctx, req)
}

// GetCustomer calls tars.admin.v1.AdminService.GetCustomer.
func (c *adminServiceClient) GetCustomer(ctx context.Context, req *connect.Request[v1.GetCustomerRequest]) (*connect.Response[v1.GetCustomerResponse], error) {
	return c.getCustomer.CallUnary(ctx, req)
}

// UpdateCustomer calls tars.admin.v1.AdminService.UpdateCustomer.
func (c *adminServiceClient) UpdateCustomer(ctx context.Context, req *connect.Request[v1.UpdateCustomerRequest]) (*connect.Response[v1.UpdateCustomerResponse], error) {
	return c.updateCustomer.CallUnary(ctx, req)
}

// DeleteCustomer calls tars.admin.v1.AdminService.DeleteCustomer.
func (c *adminServiceClient) DeleteCustomer(ctx context.Context, req *connect.Request[v1.DeleteCustomerRequest]) (*connect.Response[v1.DeleteCustomerResponse], error) {
	return c.deleteCustomer.CallUnary(ctx, req)
}

// CreateProject calls tars.admin.v1.AdminService.CreateProject.
func (c *adminServiceClient) CreateProject(ctx context.Context, req *connect.Request[v1.CreateProjectRequest]) (*connect.Response[v1.CreateProjectResponse], error) {
	return c.createProject.CallUnary(ctx, req)
}

// ListProjects calls tars.admin.v1.AdminService.ListProjects.
func (c *adminServiceClient) ListProjects(ctx context.Context, req *connect.Request[v1.ListProjectsRequest]) (*connect.Response[v1.ListProjectsResponse], error) {
	return c.listProjects.CallUnary(ctx, req)
}

// GetProject calls tars.admin.v1.AdminService.GetProject.
func (c *adminServiceClient) GetProject(ctx context.Context, req *connect.Request[v1.GetProjectRequest]) (*connect.Response[v1.GetProjectResponse], error) {
	return c.getProject.CallUnary(ctx, req)
}

// UpdateProject calls tars.admin.v1.AdminService.UpdateProject.
func (c *adminServiceClient) UpdateProject(ctx context.Context, req *connect.Request[v1.UpdateProjectRequest]) (*connect.Response[v1.UpdateProjectResponse], error) {
	return c.updateProject.CallUnary(ctx, req)
}

// DeleteProject calls tars.admin.v1.AdminService.DeleteProject.
func (c *adminServiceClient) DeleteProject(ctx context.Context, req *connect.Request[v1.DeleteProjectRequest]) (*connect.Response[v1.DeleteProjectResponse], error) {
	return c.deleteProject.CallUnary(ctx, req)
}

// AddProjectMember calls tars.admin.v1.AdminService.AddProjectMember.
func (c *adminServiceClient) AddProjectMember(ctx context.Context, req *connect.Request[v1.AddProjectMemberRequest]) (*connect.Response[v1.AddProjectMemberResponse], error) {
	return c.addProjectMember.CallUnary(ctx, req)
}

// ListProjectMembers calls tars.admin.v1.AdminService.ListProjectMembers.
func (c *adminServiceClient) ListProjectMembers(ctx context.Context, req *connect.Request[v1.ListProjectMembersRequest]) (*connect.Response[v1.ListProjectMembersResponse], error) {
	return c.listProjectMembers.CallUnary(ctx, req)
}

// UpdateProjectMember calls tars.admin.v1.AdminService.UpdateProjectMember.
func (c *adminServiceClient) UpdateProjectMember(ctx context.Context, req *connect.Request[v1.UpdateProjectMemberRequest]) (*connect.Response[v1.UpdateProjectMemberResponse], error) {
	return c.updateProjectMember.CallUnary(ctx, req)
}

// RemoveProjectMember calls tars.admin.v1.AdminService.RemoveProjectMember.
func (c *adminServiceClient) RemoveProjectMember(ctx context.Context, req *connect.Request[v1.RemoveProjectMemberRequest]) (*connect.Response[v1.RemoveProjectMemberResponse], error) {
	return c.removeProjectMember.CallUnary(ctx, req)
}

// ListModels calls tars.admin.v1.AdminService.ListModels.
func (c *adminServiceClient) ListModels(ctx context.Context, req *connect.Request[v1.ListModelsRequest]) (*connect.Response[v1.ListModelsResponse], error) {
	return c.listModels.CallUnary(ctx, req)
}

// GetModel calls tars.admin.v1.AdminService.GetModel.
func (c *adminServiceClient) GetModel(ctx context.Context, req *connect.Request[v1.GetModelRequest]) (*connect.Response[v1.GetModelResponse], error) {
	return c.getModel.CallUnary(ctx, req)
}

// AddProjectModel calls tars.admin.v1.AdminService.AddProjectModel.
func (c *adminServiceClient) AddProjectModel(ctx context.Context, req *connect.Request[v1.AddProjectModelRequest]) (*connect.Response[v1.AddProjectModelResponse], error) {
	return c.addProjectModel.CallUnary(ctx, req)
}

// ListProjectModels calls tars.admin.v1.AdminService.ListProjectModels.
func (c *adminServiceClient) ListProjectModels(ctx context.Context, req *connect.Request[v1.ListProjectModelsRequest]) (*connect.Response[v1.ListProjectModelsResponse], error) {
	return c.listProjectModels.CallUnary(ctx, req)
}

// RemoveProjectModel calls tars.admin.v1.AdminService.RemoveProjectModel.
func (c *adminServiceClient) RemoveProjectModel(ctx context.Context, req *connect.Request[v1.RemoveProjectModelRequest]) (*connect.Response[v1.RemoveProjectModelResponse], error) {
	return c.removeProjectModel.CallUnary(ctx, req)
}

// AddProjectProvider calls tars.admin.v1.AdminService.AddProjectProvider.
func (c *adminServiceClient) AddProjectProvider(ctx context.Context, req *connect.Request[v1.AddProjectProviderRequest]) (*connect.Response[v1.AddProjectProviderResponse], error) {
	return c.addProjectProvider.CallUnary(ctx, req)
}

// ListProjectProviders calls tars.admin.v1.AdminService.ListProjectProviders.
func (c *adminServiceClient) ListProjectProviders(ctx context.Context, req *connect.Request[v1.ListProjectProvidersRequest]) (*connect.Response[v1.ListProjectProvidersResponse], error) {
	return c.listProjectProviders.CallUnary(ctx, req)
}

// RemoveProjectProvider calls tars.admin.v1.AdminService.RemoveProjectProvider.
func (c *adminServiceClient) RemoveProjectProvider(ctx context.Context, req *connect.Request[v1.RemoveProjectProviderRequest]) (*connect.Response[v1.RemoveProjectProviderResponse], error) {
	return c.removeProjectProvider.CallUnary(ctx, req)
}

// AddProjectMcpServer calls tars.admin.v1.AdminService.AddProjectMcpServer.
func (c *adminServiceClient) AddProjectMcpServer(ctx context.Context, req *connect.Request[v1.AddProjectMcpServerRequest]) (*connect.Response[v1.AddProjectMcpServerResponse], error) {
	return c.addProjectMcpServer.CallUnary(ctx, req)
}

// ListProjectMcpServers calls tars.admin.v1.AdminService.ListProjectMcpServers.
func (c *adminServiceClient) ListProjectMcpServers(ctx context.Context, req *connect.Request[v1.ListProjectMcpServersRequest]) (*connect.Response[v1.ListProjectMcpServersResponse], error) {
	return c.listProjectMcpServers.CallUnary(ctx, req)
}

// RemoveProjectMcpServer calls tars.admin.v1.AdminService.RemoveProjectMcpServer.
func (c *adminServiceClient) RemoveProjectMcpServer(ctx context.Context, req *connect.Request[v1.RemoveProjectMcpServerRequest]) (*connect.Response[v1.RemoveProjectMcpServerResponse], error) {
	return c.removeProjectMcpServer.CallUnary(ctx, req)
}

// GetProjectSettings calls tars.admin.v1.AdminService.GetProjectSettings.
func (c *adminServiceClient) GetProjectSettings(ctx context.Context, req *connect.Request[v1.GetProjectSettingsRequest]) (*connect.Response[v1.GetProjectSettingsResponse], error) {
	return c.getProjectSettings.CallUnary(ctx, req)
}

// UpsertProjectSetting calls tars.admin.v1.AdminService.UpsertProjectSetting.
func (c *adminServiceClient) UpsertProjectSetting(ctx context.Context, req *connect.Request[v1.UpsertProjectSettingRequest]) (*connect.Response[v1.UpsertProjectSettingResponse], error) {
	return c.upsertProjectSetting.CallUnary(ctx, req)
}

// DeleteProjectSetting calls tars.admin.v1.AdminService.DeleteProjectSetting.
func (c *adminServiceClient) DeleteProjectSetting(ctx context.Context, req *connect.Request[v1.DeleteProjectSettingRequest]) (*connect.Response[v1.DeleteProjectSettingResponse], error) {
	return c.deleteProjectSetting.CallUnary(ctx, req)
}

// AdminServiceHandler is an implementation of the tars.admin.v1.AdminService service.
type AdminServiceHandler interface {
	// Ping endpoint for health checks and authentication testing
	Ping(context.Context, *connect.Request[v1.PingRequest]) (*connect.Response[v1.PingResponse], error)
	// Create workspace
	CreateWorkspace(context.Context, *connect.Request[v1.CreateWorkspaceRequest]) (*connect.Response[v1.CreateWorkspaceResponse], error)
	// List workspaces
	ListWorkspaces(context.Context, *connect.Request[v1.ListWorkspacesRequest]) (*connect.Response[v1.ListWorkspacesResponse], error)
	// Get workspace
	GetWorkspace(context.Context, *connect.Request[v1.GetWorkspaceRequest]) (*connect.Response[v1.GetWorkspaceResponse], error)
	// Update workspace
	UpdateWorkspace(context.Context, *connect.Request[v1.UpdateWorkspaceRequest]) (*connect.Response[v1.UpdateWorkspaceResponse], error)
	// Set the customer-facing gateway URL for a workspace data plane.
	// Writes system_settings.dataplane-url:<workspace_id> and optionally fires a PROXY_URL config event.
	SetWorkspaceURL(context.Context, *connect.Request[v1.SetWorkspaceURLRequest]) (*connect.Response[v1.SetWorkspaceURLResponse], error)
	// Assign workspace to a project (or clear back to default project by omitting project_id)
	SetWorkspaceProject(context.Context, *connect.Request[v1.SetWorkspaceProjectRequest]) (*connect.Response[v1.SetWorkspaceProjectResponse], error)
	// Delete workspace (soft delete)
	DeleteWorkspace(context.Context, *connect.Request[v1.DeleteWorkspaceRequest]) (*connect.Response[v1.DeleteWorkspaceResponse], error)
	// Create service account
	CreateServiceAccount(context.Context, *connect.Request[v1.CreateServiceAccountRequest]) (*connect.Response[v1.CreateServiceAccountResponse], error)
	// List service accounts
	ListServiceAccounts(context.Context, *connect.Request[v1.ListServiceAccountsRequest]) (*connect.Response[v1.ListServiceAccountsResponse], error)
	// Get service account
	GetServiceAccount(context.Context, *connect.Request[v1.GetServiceAccountRequest]) (*connect.Response[v1.GetServiceAccountResponse], error)
	// Revoke service account
	RevokeServiceAccount(context.Context, *connect.Request[v1.RevokeServiceAccountRequest]) (*connect.Response[v1.RevokeServiceAccountResponse], error)
	// Restore service account
	// Restores a revoked service account to active status.
	// Only one active service account per customer_id + workspace_id is allowed.
	RestoreServiceAccount(context.Context, *connect.Request[v1.RestoreServiceAccountRequest]) (*connect.Response[v1.RestoreServiceAccountResponse], error)
	// Create user token
	// Generates a JWT token for user authentication with gatekeeper.
	CreateUserToken(context.Context, *connect.Request[v1.CreateUserTokenRequest]) (*connect.Response[v1.CreateUserTokenResponse], error)
	// List user tokens
	ListUserTokens(context.Context, *connect.Request[v1.ListUserTokensRequest]) (*connect.Response[v1.ListUserTokensResponse], error)
	// Get user token
	GetUserToken(context.Context, *connect.Request[v1.GetUserTokenRequest]) (*connect.Response[v1.GetUserTokenResponse], error)
	// Revoke user token
	// Revokes a user token by its JTI (JWT ID).
	RevokeUserToken(context.Context, *connect.Request[v1.RevokeUserTokenRequest]) (*connect.Response[v1.RevokeUserTokenResponse], error)
	// Create telemetry config
	CreateTelemetryConfig(context.Context, *connect.Request[v1.CreateTelemetryConfigRequest]) (*connect.Response[v1.CreateTelemetryConfigResponse], error)
	// List telemetry configs
	ListTelemetryConfigs(context.Context, *connect.Request[v1.ListTelemetryConfigsRequest]) (*connect.Response[v1.ListTelemetryConfigsResponse], error)
	// Get telemetry config
	GetTelemetryConfig(context.Context, *connect.Request[v1.GetTelemetryConfigRequest]) (*connect.Response[v1.GetTelemetryConfigResponse], error)
	// Update telemetry config
	UpdateTelemetryConfig(context.Context, *connect.Request[v1.UpdateTelemetryConfigRequest]) (*connect.Response[v1.UpdateTelemetryConfigResponse], error)
	// Delete telemetry config
	DeleteTelemetryConfig(context.Context, *connect.Request[v1.DeleteTelemetryConfigRequest]) (*connect.Response[v1.DeleteTelemetryConfigResponse], error)
	CreateCustomer(context.Context, *connect.Request[v1.CreateCustomerRequest]) (*connect.Response[v1.CreateCustomerResponse], error)
	ListCustomers(context.Context, *connect.Request[v1.ListCustomersRequest]) (*connect.Response[v1.ListCustomersResponse], error)
	GetCustomer(context.Context, *connect.Request[v1.GetCustomerRequest]) (*connect.Response[v1.GetCustomerResponse], error)
	UpdateCustomer(context.Context, *connect.Request[v1.UpdateCustomerRequest]) (*connect.Response[v1.UpdateCustomerResponse], error)
	DeleteCustomer(context.Context, *connect.Request[v1.DeleteCustomerRequest]) (*connect.Response[v1.DeleteCustomerResponse], error)
	CreateProject(context.Context, *connect.Request[v1.CreateProjectRequest]) (*connect.Response[v1.CreateProjectResponse], error)
	ListProjects(context.Context, *connect.Request[v1.ListProjectsRequest]) (*connect.Response[v1.ListProjectsResponse], error)
	GetProject(context.Context, *connect.Request[v1.GetProjectRequest]) (*connect.Response[v1.GetProjectResponse], error)
	UpdateProject(context.Context, *connect.Request[v1.UpdateProjectRequest]) (*connect.Response[v1.UpdateProjectResponse], error)
	DeleteProject(context.Context, *connect.Request[v1.DeleteProjectRequest]) (*connect.Response[v1.DeleteProjectResponse], error)
	AddProjectMember(context.Context, *connect.Request[v1.AddProjectMemberRequest]) (*connect.Response[v1.AddProjectMemberResponse], error)
	ListProjectMembers(context.Context, *connect.Request[v1.ListProjectMembersRequest]) (*connect.Response[v1.ListProjectMembersResponse], error)
	UpdateProjectMember(context.Context, *connect.Request[v1.UpdateProjectMemberRequest]) (*connect.Response[v1.UpdateProjectMemberResponse], error)
	RemoveProjectMember(context.Context, *connect.Request[v1.RemoveProjectMemberRequest]) (*connect.Response[v1.RemoveProjectMemberResponse], error)
	ListModels(context.Context, *connect.Request[v1.ListModelsRequest]) (*connect.Response[v1.ListModelsResponse], error)
	GetModel(context.Context, *connect.Request[v1.GetModelRequest]) (*connect.Response[v1.GetModelResponse], error)
	AddProjectModel(context.Context, *connect.Request[v1.AddProjectModelRequest]) (*connect.Response[v1.AddProjectModelResponse], error)
	ListProjectModels(context.Context, *connect.Request[v1.ListProjectModelsRequest]) (*connect.Response[v1.ListProjectModelsResponse], error)
	RemoveProjectModel(context.Context, *connect.Request[v1.RemoveProjectModelRequest]) (*connect.Response[v1.RemoveProjectModelResponse], error)
	AddProjectProvider(context.Context, *connect.Request[v1.AddProjectProviderRequest]) (*connect.Response[v1.AddProjectProviderResponse], error)
	ListProjectProviders(context.Context, *connect.Request[v1.ListProjectProvidersRequest]) (*connect.Response[v1.ListProjectProvidersResponse], error)
	RemoveProjectProvider(context.Context, *connect.Request[v1.RemoveProjectProviderRequest]) (*connect.Response[v1.RemoveProjectProviderResponse], error)
	AddProjectMcpServer(context.Context, *connect.Request[v1.AddProjectMcpServerRequest]) (*connect.Response[v1.AddProjectMcpServerResponse], error)
	ListProjectMcpServers(context.Context, *connect.Request[v1.ListProjectMcpServersRequest]) (*connect.Response[v1.ListProjectMcpServersResponse], error)
	RemoveProjectMcpServer(context.Context, *connect.Request[v1.RemoveProjectMcpServerRequest]) (*connect.Response[v1.RemoveProjectMcpServerResponse], error)
	GetProjectSettings(context.Context, *connect.Request[v1.GetProjectSettingsRequest]) (*connect.Response[v1.GetProjectSettingsResponse], error)
	UpsertProjectSetting(context.Context, *connect.Request[v1.UpsertProjectSettingRequest]) (*connect.Response[v1.UpsertProjectSettingResponse], error)
	DeleteProjectSetting(context.Context, *connect.Request[v1.DeleteProjectSettingRequest]) (*connect.Response[v1.DeleteProjectSettingResponse], error)
}

// NewAdminServiceHandler builds an HTTP handler from the service implementation. It returns the
// path on which to mount the handler and the handler itself.
//
// By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf
// and JSON codecs. They also support gzip compression.
func NewAdminServiceHandler(svc AdminServiceHandler, opts ...connect.HandlerOption) (string, http.Handler) {
	adminServiceMethods := v1.File_tars_admin_v1_admin_proto.Services().ByName("AdminService").Methods()
	adminServicePingHandler := connect.NewUnaryHandler(
		AdminServicePingProcedure,
		svc.Ping,
		connect.WithSchema(adminServiceMethods.ByName("Ping")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceCreateWorkspaceHandler := connect.NewUnaryHandler(
		AdminServiceCreateWorkspaceProcedure,
		svc.CreateWorkspace,
		connect.WithSchema(adminServiceMethods.ByName("CreateWorkspace")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceListWorkspacesHandler := connect.NewUnaryHandler(
		AdminServiceListWorkspacesProcedure,
		svc.ListWorkspaces,
		connect.WithSchema(adminServiceMethods.ByName("ListWorkspaces")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceGetWorkspaceHandler := connect.NewUnaryHandler(
		AdminServiceGetWorkspaceProcedure,
		svc.GetWorkspace,
		connect.WithSchema(adminServiceMethods.ByName("GetWorkspace")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceUpdateWorkspaceHandler := connect.NewUnaryHandler(
		AdminServiceUpdateWorkspaceProcedure,
		svc.UpdateWorkspace,
		connect.WithSchema(adminServiceMethods.ByName("UpdateWorkspace")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceSetWorkspaceURLHandler := connect.NewUnaryHandler(
		AdminServiceSetWorkspaceURLProcedure,
		svc.SetWorkspaceURL,
		connect.WithSchema(adminServiceMethods.ByName("SetWorkspaceURL")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceSetWorkspaceProjectHandler := connect.NewUnaryHandler(
		AdminServiceSetWorkspaceProjectProcedure,
		svc.SetWorkspaceProject,
		connect.WithSchema(adminServiceMethods.ByName("SetWorkspaceProject")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceDeleteWorkspaceHandler := connect.NewUnaryHandler(
		AdminServiceDeleteWorkspaceProcedure,
		svc.DeleteWorkspace,
		connect.WithSchema(adminServiceMethods.ByName("DeleteWorkspace")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceCreateServiceAccountHandler := connect.NewUnaryHandler(
		AdminServiceCreateServiceAccountProcedure,
		svc.CreateServiceAccount,
		connect.WithSchema(adminServiceMethods.ByName("CreateServiceAccount")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceListServiceAccountsHandler := connect.NewUnaryHandler(
		AdminServiceListServiceAccountsProcedure,
		svc.ListServiceAccounts,
		connect.WithSchema(adminServiceMethods.ByName("ListServiceAccounts")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceGetServiceAccountHandler := connect.NewUnaryHandler(
		AdminServiceGetServiceAccountProcedure,
		svc.GetServiceAccount,
		connect.WithSchema(adminServiceMethods.ByName("GetServiceAccount")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceRevokeServiceAccountHandler := connect.NewUnaryHandler(
		AdminServiceRevokeServiceAccountProcedure,
		svc.RevokeServiceAccount,
		connect.WithSchema(adminServiceMethods.ByName("RevokeServiceAccount")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceRestoreServiceAccountHandler := connect.NewUnaryHandler(
		AdminServiceRestoreServiceAccountProcedure,
		svc.RestoreServiceAccount,
		connect.WithSchema(adminServiceMethods.ByName("RestoreServiceAccount")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceCreateUserTokenHandler := connect.NewUnaryHandler(
		AdminServiceCreateUserTokenProcedure,
		svc.CreateUserToken,
		connect.WithSchema(adminServiceMethods.ByName("CreateUserToken")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceListUserTokensHandler := connect.NewUnaryHandler(
		AdminServiceListUserTokensProcedure,
		svc.ListUserTokens,
		connect.WithSchema(adminServiceMethods.ByName("ListUserTokens")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceGetUserTokenHandler := connect.NewUnaryHandler(
		AdminServiceGetUserTokenProcedure,
		svc.GetUserToken,
		connect.WithSchema(adminServiceMethods.ByName("GetUserToken")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceRevokeUserTokenHandler := connect.NewUnaryHandler(
		AdminServiceRevokeUserTokenProcedure,
		svc.RevokeUserToken,
		connect.WithSchema(adminServiceMethods.ByName("RevokeUserToken")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceCreateTelemetryConfigHandler := connect.NewUnaryHandler(
		AdminServiceCreateTelemetryConfigProcedure,
		svc.CreateTelemetryConfig,
		connect.WithSchema(adminServiceMethods.ByName("CreateTelemetryConfig")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceListTelemetryConfigsHandler := connect.NewUnaryHandler(
		AdminServiceListTelemetryConfigsProcedure,
		svc.ListTelemetryConfigs,
		connect.WithSchema(adminServiceMethods.ByName("ListTelemetryConfigs")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceGetTelemetryConfigHandler := connect.NewUnaryHandler(
		AdminServiceGetTelemetryConfigProcedure,
		svc.GetTelemetryConfig,
		connect.WithSchema(adminServiceMethods.ByName("GetTelemetryConfig")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceUpdateTelemetryConfigHandler := connect.NewUnaryHandler(
		AdminServiceUpdateTelemetryConfigProcedure,
		svc.UpdateTelemetryConfig,
		connect.WithSchema(adminServiceMethods.ByName("UpdateTelemetryConfig")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceDeleteTelemetryConfigHandler := connect.NewUnaryHandler(
		AdminServiceDeleteTelemetryConfigProcedure,
		svc.DeleteTelemetryConfig,
		connect.WithSchema(adminServiceMethods.ByName("DeleteTelemetryConfig")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceCreateCustomerHandler := connect.NewUnaryHandler(
		AdminServiceCreateCustomerProcedure,
		svc.CreateCustomer,
		connect.WithSchema(adminServiceMethods.ByName("CreateCustomer")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceListCustomersHandler := connect.NewUnaryHandler(
		AdminServiceListCustomersProcedure,
		svc.ListCustomers,
		connect.WithSchema(adminServiceMethods.ByName("ListCustomers")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceGetCustomerHandler := connect.NewUnaryHandler(
		AdminServiceGetCustomerProcedure,
		svc.GetCustomer,
		connect.WithSchema(adminServiceMethods.ByName("GetCustomer")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceUpdateCustomerHandler := connect.NewUnaryHandler(
		AdminServiceUpdateCustomerProcedure,
		svc.UpdateCustomer,
		connect.WithSchema(adminServiceMethods.ByName("UpdateCustomer")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceDeleteCustomerHandler := connect.NewUnaryHandler(
		AdminServiceDeleteCustomerProcedure,
		svc.DeleteCustomer,
		connect.WithSchema(adminServiceMethods.ByName("DeleteCustomer")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceCreateProjectHandler := connect.NewUnaryHandler(
		AdminServiceCreateProjectProcedure,
		svc.CreateProject,
		connect.WithSchema(adminServiceMethods.ByName("CreateProject")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceListProjectsHandler := connect.NewUnaryHandler(
		AdminServiceListProjectsProcedure,
		svc.ListProjects,
		connect.WithSchema(adminServiceMethods.ByName("ListProjects")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceGetProjectHandler := connect.NewUnaryHandler(
		AdminServiceGetProjectProcedure,
		svc.GetProject,
		connect.WithSchema(adminServiceMethods.ByName("GetProject")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceUpdateProjectHandler := connect.NewUnaryHandler(
		AdminServiceUpdateProjectProcedure,
		svc.UpdateProject,
		connect.WithSchema(adminServiceMethods.ByName("UpdateProject")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceDeleteProjectHandler := connect.NewUnaryHandler(
		AdminServiceDeleteProjectProcedure,
		svc.DeleteProject,
		connect.WithSchema(adminServiceMethods.ByName("DeleteProject")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceAddProjectMemberHandler := connect.NewUnaryHandler(
		AdminServiceAddProjectMemberProcedure,
		svc.AddProjectMember,
		connect.WithSchema(adminServiceMethods.ByName("AddProjectMember")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceListProjectMembersHandler := connect.NewUnaryHandler(
		AdminServiceListProjectMembersProcedure,
		svc.ListProjectMembers,
		connect.WithSchema(adminServiceMethods.ByName("ListProjectMembers")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceUpdateProjectMemberHandler := connect.NewUnaryHandler(
		AdminServiceUpdateProjectMemberProcedure,
		svc.UpdateProjectMember,
		connect.WithSchema(adminServiceMethods.ByName("UpdateProjectMember")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceRemoveProjectMemberHandler := connect.NewUnaryHandler(
		AdminServiceRemoveProjectMemberProcedure,
		svc.RemoveProjectMember,
		connect.WithSchema(adminServiceMethods.ByName("RemoveProjectMember")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceListModelsHandler := connect.NewUnaryHandler(
		AdminServiceListModelsProcedure,
		svc.ListModels,
		connect.WithSchema(adminServiceMethods.ByName("ListModels")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceGetModelHandler := connect.NewUnaryHandler(
		AdminServiceGetModelProcedure,
		svc.GetModel,
		connect.WithSchema(adminServiceMethods.ByName("GetModel")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceAddProjectModelHandler := connect.NewUnaryHandler(
		AdminServiceAddProjectModelProcedure,
		svc.AddProjectModel,
		connect.WithSchema(adminServiceMethods.ByName("AddProjectModel")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceListProjectModelsHandler := connect.NewUnaryHandler(
		AdminServiceListProjectModelsProcedure,
		svc.ListProjectModels,
		connect.WithSchema(adminServiceMethods.ByName("ListProjectModels")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceRemoveProjectModelHandler := connect.NewUnaryHandler(
		AdminServiceRemoveProjectModelProcedure,
		svc.RemoveProjectModel,
		connect.WithSchema(adminServiceMethods.ByName("RemoveProjectModel")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceAddProjectProviderHandler := connect.NewUnaryHandler(
		AdminServiceAddProjectProviderProcedure,
		svc.AddProjectProvider,
		connect.WithSchema(adminServiceMethods.ByName("AddProjectProvider")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceListProjectProvidersHandler := connect.NewUnaryHandler(
		AdminServiceListProjectProvidersProcedure,
		svc.ListProjectProviders,
		connect.WithSchema(adminServiceMethods.ByName("ListProjectProviders")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceRemoveProjectProviderHandler := connect.NewUnaryHandler(
		AdminServiceRemoveProjectProviderProcedure,
		svc.RemoveProjectProvider,
		connect.WithSchema(adminServiceMethods.ByName("RemoveProjectProvider")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceAddProjectMcpServerHandler := connect.NewUnaryHandler(
		AdminServiceAddProjectMcpServerProcedure,
		svc.AddProjectMcpServer,
		connect.WithSchema(adminServiceMethods.ByName("AddProjectMcpServer")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceListProjectMcpServersHandler := connect.NewUnaryHandler(
		AdminServiceListProjectMcpServersProcedure,
		svc.ListProjectMcpServers,
		connect.WithSchema(adminServiceMethods.ByName("ListProjectMcpServers")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceRemoveProjectMcpServerHandler := connect.NewUnaryHandler(
		AdminServiceRemoveProjectMcpServerProcedure,
		svc.RemoveProjectMcpServer,
		connect.WithSchema(adminServiceMethods.ByName("RemoveProjectMcpServer")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceGetProjectSettingsHandler := connect.NewUnaryHandler(
		AdminServiceGetProjectSettingsProcedure,
		svc.GetProjectSettings,
		connect.WithSchema(adminServiceMethods.ByName("GetProjectSettings")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceUpsertProjectSettingHandler := connect.NewUnaryHandler(
		AdminServiceUpsertProjectSettingProcedure,
		svc.UpsertProjectSetting,
		connect.WithSchema(adminServiceMethods.ByName("UpsertProjectSetting")),
		connect.WithHandlerOptions(opts...),
	)
	adminServiceDeleteProjectSettingHandler := connect.NewUnaryHandler(
		AdminServiceDeleteProjectSettingProcedure,
		svc.DeleteProjectSetting,
		connect.WithSchema(adminServiceMethods.ByName("DeleteProjectSetting")),
		connect.WithHandlerOptions(opts...),
	)
	return "/tars.admin.v1.AdminService/", http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
		switch r.URL.Path {
		case AdminServicePingProcedure:
			adminServicePingHandler.ServeHTTP(w, r)
		case AdminServiceCreateWorkspaceProcedure:
			adminServiceCreateWorkspaceHandler.ServeHTTP(w, r)
		case AdminServiceListWorkspacesProcedure:
			adminServiceListWorkspacesHandler.ServeHTTP(w, r)
		case AdminServiceGetWorkspaceProcedure:
			adminServiceGetWorkspaceHandler.ServeHTTP(w, r)
		case AdminServiceUpdateWorkspaceProcedure:
			adminServiceUpdateWorkspaceHandler.ServeHTTP(w, r)
		case AdminServiceSetWorkspaceURLProcedure:
			adminServiceSetWorkspaceURLHandler.ServeHTTP(w, r)
		case AdminServiceSetWorkspaceProjectProcedure:
			adminServiceSetWorkspaceProjectHandler.ServeHTTP(w, r)
		case AdminServiceDeleteWorkspaceProcedure:
			adminServiceDeleteWorkspaceHandler.ServeHTTP(w, r)
		case AdminServiceCreateServiceAccountProcedure:
			adminServiceCreateServiceAccountHandler.ServeHTTP(w, r)
		case AdminServiceListServiceAccountsProcedure:
			adminServiceListServiceAccountsHandler.ServeHTTP(w, r)
		case AdminServiceGetServiceAccountProcedure:
			adminServiceGetServiceAccountHandler.ServeHTTP(w, r)
		case AdminServiceRevokeServiceAccountProcedure:
			adminServiceRevokeServiceAccountHandler.ServeHTTP(w, r)
		case AdminServiceRestoreServiceAccountProcedure:
			adminServiceRestoreServiceAccountHandler.ServeHTTP(w, r)
		case AdminServiceCreateUserTokenProcedure:
			adminServiceCreateUserTokenHandler.ServeHTTP(w, r)
		case AdminServiceListUserTokensProcedure:
			adminServiceListUserTokensHandler.ServeHTTP(w, r)
		case AdminServiceGetUserTokenProcedure:
			adminServiceGetUserTokenHandler.ServeHTTP(w, r)
		case AdminServiceRevokeUserTokenProcedure:
			adminServiceRevokeUserTokenHandler.ServeHTTP(w, r)
		case AdminServiceCreateTelemetryConfigProcedure:
			adminServiceCreateTelemetryConfigHandler.ServeHTTP(w, r)
		case AdminServiceListTelemetryConfigsProcedure:
			adminServiceListTelemetryConfigsHandler.ServeHTTP(w, r)
		case AdminServiceGetTelemetryConfigProcedure:
			adminServiceGetTelemetryConfigHandler.ServeHTTP(w, r)
		case AdminServiceUpdateTelemetryConfigProcedure:
			adminServiceUpdateTelemetryConfigHandler.ServeHTTP(w, r)
		case AdminServiceDeleteTelemetryConfigProcedure:
			adminServiceDeleteTelemetryConfigHandler.ServeHTTP(w, r)
		case AdminServiceCreateCustomerProcedure:
			adminServiceCreateCustomerHandler.ServeHTTP(w, r)
		case AdminServiceListCustomersProcedure:
			adminServiceListCustomersHandler.ServeHTTP(w, r)
		case AdminServiceGetCustomerProcedure:
			adminServiceGetCustomerHandler.ServeHTTP(w, r)
		case AdminServiceUpdateCustomerProcedure:
			adminServiceUpdateCustomerHandler.ServeHTTP(w, r)
		case AdminServiceDeleteCustomerProcedure:
			adminServiceDeleteCustomerHandler.ServeHTTP(w, r)
		case AdminServiceCreateProjectProcedure:
			adminServiceCreateProjectHandler.ServeHTTP(w, r)
		case AdminServiceListProjectsProcedure:
			adminServiceListProjectsHandler.ServeHTTP(w, r)
		case AdminServiceGetProjectProcedure:
			adminServiceGetProjectHandler.ServeHTTP(w, r)
		case AdminServiceUpdateProjectProcedure:
			adminServiceUpdateProjectHandler.ServeHTTP(w, r)
		case AdminServiceDeleteProjectProcedure:
			adminServiceDeleteProjectHandler.ServeHTTP(w, r)
		case AdminServiceAddProjectMemberProcedure:
			adminServiceAddProjectMemberHandler.ServeHTTP(w, r)
		case AdminServiceListProjectMembersProcedure:
			adminServiceListProjectMembersHandler.ServeHTTP(w, r)
		case AdminServiceUpdateProjectMemberProcedure:
			adminServiceUpdateProjectMemberHandler.ServeHTTP(w, r)
		case AdminServiceRemoveProjectMemberProcedure:
			adminServiceRemoveProjectMemberHandler.ServeHTTP(w, r)
		case AdminServiceListModelsProcedure:
			adminServiceListModelsHandler.ServeHTTP(w, r)
		case AdminServiceGetModelProcedure:
			adminServiceGetModelHandler.ServeHTTP(w, r)
		case AdminServiceAddProjectModelProcedure:
			adminServiceAddProjectModelHandler.ServeHTTP(w, r)
		case AdminServiceListProjectModelsProcedure:
			adminServiceListProjectModelsHandler.ServeHTTP(w, r)
		case AdminServiceRemoveProjectModelProcedure:
			adminServiceRemoveProjectModelHandler.ServeHTTP(w, r)
		case AdminServiceAddProjectProviderProcedure:
			adminServiceAddProjectProviderHandler.ServeHTTP(w, r)
		case AdminServiceListProjectProvidersProcedure:
			adminServiceListProjectProvidersHandler.ServeHTTP(w, r)
		case AdminServiceRemoveProjectProviderProcedure:
			adminServiceRemoveProjectProviderHandler.ServeHTTP(w, r)
		case AdminServiceAddProjectMcpServerProcedure:
			adminServiceAddProjectMcpServerHandler.ServeHTTP(w, r)
		case AdminServiceListProjectMcpServersProcedure:
			adminServiceListProjectMcpServersHandler.ServeHTTP(w, r)
		case AdminServiceRemoveProjectMcpServerProcedure:
			adminServiceRemoveProjectMcpServerHandler.ServeHTTP(w, r)
		case AdminServiceGetProjectSettingsProcedure:
			adminServiceGetProjectSettingsHandler.ServeHTTP(w, r)
		case AdminServiceUpsertProjectSettingProcedure:
			adminServiceUpsertProjectSettingHandler.ServeHTTP(w, r)
		case AdminServiceDeleteProjectSettingProcedure:
			adminServiceDeleteProjectSettingHandler.ServeHTTP(w, r)
		default:
			http.NotFound(w, r)
		}
	})
}

// UnimplementedAdminServiceHandler returns CodeUnimplemented from all methods.
type UnimplementedAdminServiceHandler struct{}

func (UnimplementedAdminServiceHandler) Ping(context.Context, *connect.Request[v1.PingRequest]) (*connect.Response[v1.PingResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.Ping is not implemented"))
}

func (UnimplementedAdminServiceHandler) CreateWorkspace(context.Context, *connect.Request[v1.CreateWorkspaceRequest]) (*connect.Response[v1.CreateWorkspaceResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.CreateWorkspace is not implemented"))
}

func (UnimplementedAdminServiceHandler) ListWorkspaces(context.Context, *connect.Request[v1.ListWorkspacesRequest]) (*connect.Response[v1.ListWorkspacesResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.ListWorkspaces is not implemented"))
}

func (UnimplementedAdminServiceHandler) GetWorkspace(context.Context, *connect.Request[v1.GetWorkspaceRequest]) (*connect.Response[v1.GetWorkspaceResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.GetWorkspace is not implemented"))
}

func (UnimplementedAdminServiceHandler) UpdateWorkspace(context.Context, *connect.Request[v1.UpdateWorkspaceRequest]) (*connect.Response[v1.UpdateWorkspaceResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.UpdateWorkspace is not implemented"))
}

func (UnimplementedAdminServiceHandler) SetWorkspaceURL(context.Context, *connect.Request[v1.SetWorkspaceURLRequest]) (*connect.Response[v1.SetWorkspaceURLResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.SetWorkspaceURL is not implemented"))
}

func (UnimplementedAdminServiceHandler) SetWorkspaceProject(context.Context, *connect.Request[v1.SetWorkspaceProjectRequest]) (*connect.Response[v1.SetWorkspaceProjectResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.SetWorkspaceProject is not implemented"))
}

func (UnimplementedAdminServiceHandler) DeleteWorkspace(context.Context, *connect.Request[v1.DeleteWorkspaceRequest]) (*connect.Response[v1.DeleteWorkspaceResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.DeleteWorkspace is not implemented"))
}

func (UnimplementedAdminServiceHandler) CreateServiceAccount(context.Context, *connect.Request[v1.CreateServiceAccountRequest]) (*connect.Response[v1.CreateServiceAccountResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.CreateServiceAccount is not implemented"))
}

func (UnimplementedAdminServiceHandler) ListServiceAccounts(context.Context, *connect.Request[v1.ListServiceAccountsRequest]) (*connect.Response[v1.ListServiceAccountsResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.ListServiceAccounts is not implemented"))
}

func (UnimplementedAdminServiceHandler) GetServiceAccount(context.Context, *connect.Request[v1.GetServiceAccountRequest]) (*connect.Response[v1.GetServiceAccountResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.GetServiceAccount is not implemented"))
}

func (UnimplementedAdminServiceHandler) RevokeServiceAccount(context.Context, *connect.Request[v1.RevokeServiceAccountRequest]) (*connect.Response[v1.RevokeServiceAccountResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.RevokeServiceAccount is not implemented"))
}

func (UnimplementedAdminServiceHandler) RestoreServiceAccount(context.Context, *connect.Request[v1.RestoreServiceAccountRequest]) (*connect.Response[v1.RestoreServiceAccountResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.RestoreServiceAccount is not implemented"))
}

func (UnimplementedAdminServiceHandler) CreateUserToken(context.Context, *connect.Request[v1.CreateUserTokenRequest]) (*connect.Response[v1.CreateUserTokenResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.CreateUserToken is not implemented"))
}

func (UnimplementedAdminServiceHandler) ListUserTokens(context.Context, *connect.Request[v1.ListUserTokensRequest]) (*connect.Response[v1.ListUserTokensResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.ListUserTokens is not implemented"))
}

func (UnimplementedAdminServiceHandler) GetUserToken(context.Context, *connect.Request[v1.GetUserTokenRequest]) (*connect.Response[v1.GetUserTokenResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.GetUserToken is not implemented"))
}

func (UnimplementedAdminServiceHandler) RevokeUserToken(context.Context, *connect.Request[v1.RevokeUserTokenRequest]) (*connect.Response[v1.RevokeUserTokenResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.RevokeUserToken is not implemented"))
}

func (UnimplementedAdminServiceHandler) CreateTelemetryConfig(context.Context, *connect.Request[v1.CreateTelemetryConfigRequest]) (*connect.Response[v1.CreateTelemetryConfigResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.CreateTelemetryConfig is not implemented"))
}

func (UnimplementedAdminServiceHandler) ListTelemetryConfigs(context.Context, *connect.Request[v1.ListTelemetryConfigsRequest]) (*connect.Response[v1.ListTelemetryConfigsResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.ListTelemetryConfigs is not implemented"))
}

func (UnimplementedAdminServiceHandler) GetTelemetryConfig(context.Context, *connect.Request[v1.GetTelemetryConfigRequest]) (*connect.Response[v1.GetTelemetryConfigResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.GetTelemetryConfig is not implemented"))
}

func (UnimplementedAdminServiceHandler) UpdateTelemetryConfig(context.Context, *connect.Request[v1.UpdateTelemetryConfigRequest]) (*connect.Response[v1.UpdateTelemetryConfigResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.UpdateTelemetryConfig is not implemented"))
}

func (UnimplementedAdminServiceHandler) DeleteTelemetryConfig(context.Context, *connect.Request[v1.DeleteTelemetryConfigRequest]) (*connect.Response[v1.DeleteTelemetryConfigResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.DeleteTelemetryConfig is not implemented"))
}

func (UnimplementedAdminServiceHandler) CreateCustomer(context.Context, *connect.Request[v1.CreateCustomerRequest]) (*connect.Response[v1.CreateCustomerResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.CreateCustomer is not implemented"))
}

func (UnimplementedAdminServiceHandler) ListCustomers(context.Context, *connect.Request[v1.ListCustomersRequest]) (*connect.Response[v1.ListCustomersResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.ListCustomers is not implemented"))
}

func (UnimplementedAdminServiceHandler) GetCustomer(context.Context, *connect.Request[v1.GetCustomerRequest]) (*connect.Response[v1.GetCustomerResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.GetCustomer is not implemented"))
}

func (UnimplementedAdminServiceHandler) UpdateCustomer(context.Context, *connect.Request[v1.UpdateCustomerRequest]) (*connect.Response[v1.UpdateCustomerResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.UpdateCustomer is not implemented"))
}

func (UnimplementedAdminServiceHandler) DeleteCustomer(context.Context, *connect.Request[v1.DeleteCustomerRequest]) (*connect.Response[v1.DeleteCustomerResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.DeleteCustomer is not implemented"))
}

func (UnimplementedAdminServiceHandler) CreateProject(context.Context, *connect.Request[v1.CreateProjectRequest]) (*connect.Response[v1.CreateProjectResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.CreateProject is not implemented"))
}

func (UnimplementedAdminServiceHandler) ListProjects(context.Context, *connect.Request[v1.ListProjectsRequest]) (*connect.Response[v1.ListProjectsResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.ListProjects is not implemented"))
}

func (UnimplementedAdminServiceHandler) GetProject(context.Context, *connect.Request[v1.GetProjectRequest]) (*connect.Response[v1.GetProjectResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.GetProject is not implemented"))
}

func (UnimplementedAdminServiceHandler) UpdateProject(context.Context, *connect.Request[v1.UpdateProjectRequest]) (*connect.Response[v1.UpdateProjectResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.UpdateProject is not implemented"))
}

func (UnimplementedAdminServiceHandler) DeleteProject(context.Context, *connect.Request[v1.DeleteProjectRequest]) (*connect.Response[v1.DeleteProjectResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.DeleteProject is not implemented"))
}

func (UnimplementedAdminServiceHandler) AddProjectMember(context.Context, *connect.Request[v1.AddProjectMemberRequest]) (*connect.Response[v1.AddProjectMemberResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.AddProjectMember is not implemented"))
}

func (UnimplementedAdminServiceHandler) ListProjectMembers(context.Context, *connect.Request[v1.ListProjectMembersRequest]) (*connect.Response[v1.ListProjectMembersResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.ListProjectMembers is not implemented"))
}

func (UnimplementedAdminServiceHandler) UpdateProjectMember(context.Context, *connect.Request[v1.UpdateProjectMemberRequest]) (*connect.Response[v1.UpdateProjectMemberResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.UpdateProjectMember is not implemented"))
}

func (UnimplementedAdminServiceHandler) RemoveProjectMember(context.Context, *connect.Request[v1.RemoveProjectMemberRequest]) (*connect.Response[v1.RemoveProjectMemberResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.RemoveProjectMember is not implemented"))
}

func (UnimplementedAdminServiceHandler) ListModels(context.Context, *connect.Request[v1.ListModelsRequest]) (*connect.Response[v1.ListModelsResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.ListModels is not implemented"))
}

func (UnimplementedAdminServiceHandler) GetModel(context.Context, *connect.Request[v1.GetModelRequest]) (*connect.Response[v1.GetModelResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.GetModel is not implemented"))
}

func (UnimplementedAdminServiceHandler) AddProjectModel(context.Context, *connect.Request[v1.AddProjectModelRequest]) (*connect.Response[v1.AddProjectModelResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.AddProjectModel is not implemented"))
}

func (UnimplementedAdminServiceHandler) ListProjectModels(context.Context, *connect.Request[v1.ListProjectModelsRequest]) (*connect.Response[v1.ListProjectModelsResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.ListProjectModels is not implemented"))
}

func (UnimplementedAdminServiceHandler) RemoveProjectModel(context.Context, *connect.Request[v1.RemoveProjectModelRequest]) (*connect.Response[v1.RemoveProjectModelResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.RemoveProjectModel is not implemented"))
}

func (UnimplementedAdminServiceHandler) AddProjectProvider(context.Context, *connect.Request[v1.AddProjectProviderRequest]) (*connect.Response[v1.AddProjectProviderResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.AddProjectProvider is not implemented"))
}

func (UnimplementedAdminServiceHandler) ListProjectProviders(context.Context, *connect.Request[v1.ListProjectProvidersRequest]) (*connect.Response[v1.ListProjectProvidersResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.ListProjectProviders is not implemented"))
}

func (UnimplementedAdminServiceHandler) RemoveProjectProvider(context.Context, *connect.Request[v1.RemoveProjectProviderRequest]) (*connect.Response[v1.RemoveProjectProviderResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.RemoveProjectProvider is not implemented"))
}

func (UnimplementedAdminServiceHandler) AddProjectMcpServer(context.Context, *connect.Request[v1.AddProjectMcpServerRequest]) (*connect.Response[v1.AddProjectMcpServerResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.AddProjectMcpServer is not implemented"))
}

func (UnimplementedAdminServiceHandler) ListProjectMcpServers(context.Context, *connect.Request[v1.ListProjectMcpServersRequest]) (*connect.Response[v1.ListProjectMcpServersResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.ListProjectMcpServers is not implemented"))
}

func (UnimplementedAdminServiceHandler) RemoveProjectMcpServer(context.Context, *connect.Request[v1.RemoveProjectMcpServerRequest]) (*connect.Response[v1.RemoveProjectMcpServerResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.RemoveProjectMcpServer is not implemented"))
}

func (UnimplementedAdminServiceHandler) GetProjectSettings(context.Context, *connect.Request[v1.GetProjectSettingsRequest]) (*connect.Response[v1.GetProjectSettingsResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.GetProjectSettings is not implemented"))
}

func (UnimplementedAdminServiceHandler) UpsertProjectSetting(context.Context, *connect.Request[v1.UpsertProjectSettingRequest]) (*connect.Response[v1.UpsertProjectSettingResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.UpsertProjectSetting is not implemented"))
}

func (UnimplementedAdminServiceHandler) DeleteProjectSetting(context.Context, *connect.Request[v1.DeleteProjectSettingRequest]) (*connect.Response[v1.DeleteProjectSettingResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.admin.v1.AdminService.DeleteProjectSetting is not implemented"))
}
