// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.10
// 	protoc        (unknown)
// source: tars/test/v1/test.proto

package testv1

import (
	_ "github.com/tetrateio/agentrouter-go/genapi/api/tars/auth/v1"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type PingRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *PingRequest) Reset() {
	*x = PingRequest{}
	mi := &file_tars_test_v1_test_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *PingRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PingRequest) ProtoMessage() {}

func (x *PingRequest) ProtoReflect() protoreflect.Message {
	mi := &file_tars_test_v1_test_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PingRequest.ProtoReflect.Descriptor instead.
func (*PingRequest) Descriptor() ([]byte, []int) {
	return file_tars_test_v1_test_proto_rawDescGZIP(), []int{0}
}

type PingResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Indicates if the authentication was successful
	Authenticated bool `protobuf:"varint,1,opt,name=authenticated,proto3" json:"authenticated,omitempty"`
	// The authenticated client email from the JWT
	ClientEmail string `protobuf:"bytes,2,opt,name=client_email,json=clientEmail,proto3" json:"client_email,omitempty"`
	// The issuer (iss) claim from the JWT
	Issuer string `protobuf:"bytes,3,opt,name=issuer,proto3" json:"issuer,omitempty"`
	// The audience (aud) claim from the JWT
	Audience string `protobuf:"bytes,4,opt,name=audience,proto3" json:"audience,omitempty"`
	// The subject (sub) claim from the JWT
	Subject string `protobuf:"bytes,5,opt,name=subject,proto3" json:"subject,omitempty"`
	// Scopes/permissions from the JWT
	Scopes []string `protobuf:"bytes,6,rep,name=scopes,proto3" json:"scopes,omitempty"`
	// Token expiration time
	ExpiresAt *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=expires_at,json=expiresAt,proto3" json:"expires_at,omitempty"`
	// Token issued at time
	IssuedAt *timestamppb.Timestamp `protobuf:"bytes,8,opt,name=issued_at,json=issuedAt,proto3" json:"issued_at,omitempty"`
	// Server timestamp
	ServerTime *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=server_time,json=serverTime,proto3" json:"server_time,omitempty"`
	// Additional claims from the JWT (optional custom claims)
	CustomClaims  map[string]string `protobuf:"bytes,10,rep,name=custom_claims,json=customClaims,proto3" json:"custom_claims,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *PingResponse) Reset() {
	*x = PingResponse{}
	mi := &file_tars_test_v1_test_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *PingResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PingResponse) ProtoMessage() {}

func (x *PingResponse) ProtoReflect() protoreflect.Message {
	mi := &file_tars_test_v1_test_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PingResponse.ProtoReflect.Descriptor instead.
func (*PingResponse) Descriptor() ([]byte, []int) {
	return file_tars_test_v1_test_proto_rawDescGZIP(), []int{1}
}

func (x *PingResponse) GetAuthenticated() bool {
	if x != nil {
		return x.Authenticated
	}
	return false
}

func (x *PingResponse) GetClientEmail() string {
	if x != nil {
		return x.ClientEmail
	}
	return ""
}

func (x *PingResponse) GetIssuer() string {
	if x != nil {
		return x.Issuer
	}
	return ""
}

func (x *PingResponse) GetAudience() string {
	if x != nil {
		return x.Audience
	}
	return ""
}

func (x *PingResponse) GetSubject() string {
	if x != nil {
		return x.Subject
	}
	return ""
}

func (x *PingResponse) GetScopes() []string {
	if x != nil {
		return x.Scopes
	}
	return nil
}

func (x *PingResponse) GetExpiresAt() *timestamppb.Timestamp {
	if x != nil {
		return x.ExpiresAt
	}
	return nil
}

func (x *PingResponse) GetIssuedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.IssuedAt
	}
	return nil
}

func (x *PingResponse) GetServerTime() *timestamppb.Timestamp {
	if x != nil {
		return x.ServerTime
	}
	return nil
}

func (x *PingResponse) GetCustomClaims() map[string]string {
	if x != nil {
		return x.CustomClaims
	}
	return nil
}

var File_tars_test_v1_test_proto protoreflect.FileDescriptor

const file_tars_test_v1_test_proto_rawDesc = "" +
	"\n" +
	"\x17tars/test/v1/test.proto\x12\ftars.test.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\"\r\n" +
	"\vPingRequest\"\x82\x04\n" +
	"\fPingResponse\x12$\n" +
	"\rauthenticated\x18\x01 \x01(\bR\rauthenticated\x12!\n" +
	"\fclient_email\x18\x02 \x01(\tR\vclientEmail\x12\x16\n" +
	"\x06issuer\x18\x03 \x01(\tR\x06issuer\x12\x1a\n" +
	"\baudience\x18\x04 \x01(\tR\baudience\x12\x18\n" +
	"\asubject\x18\x05 \x01(\tR\asubject\x12\x16\n" +
	"\x06scopes\x18\x06 \x03(\tR\x06scopes\x129\n" +
	"\n" +
	"expires_at\x18\a \x01(\v2\x1a.google.protobuf.TimestampR\texpiresAt\x127\n" +
	"\tissued_at\x18\b \x01(\v2\x1a.google.protobuf.TimestampR\bissuedAt\x12;\n" +
	"\vserver_time\x18\t \x01(\v2\x1a.google.protobuf.TimestampR\n" +
	"serverTime\x12Q\n" +
	"\rcustom_claims\x18\n" +
	" \x03(\v2,.tars.test.v1.PingResponse.CustomClaimsEntryR\fcustomClaims\x1a?\n" +
	"\x11CustomClaimsEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n" +
	"\x05value\x18\x02 \x01(\tR\x05value:\x028\x012s\n" +
	"\vTestService\x12d\n" +
	"\x04Ping\x12\x19.tars.test.v1.PingRequest\x1a\x1a.tars.test.v1.PingResponse\"%\x8a\xb5\x18\t\n" +
	"\x01\x02\x12\x04read\x82\xd3\xe4\x93\x02\x0f\x12\r/test/v1/ping\x90\x02\x01B\xa4\x01\n" +
	"\x10com.tars.test.v1B\tTestProtoP\x01Z3github.com/tetrateio/fraser/api/tars/test/v1;testv1\xa2\x02\x03TTX\xaa\x02\fTars.Test.V1\xca\x02\fTars\\Test\\V1\xe2\x02\x18Tars\\Test\\V1\\GPBMetadata\xea\x02\x0eTars::Test::V1b\x06proto3"

var (
	file_tars_test_v1_test_proto_rawDescOnce sync.Once
	file_tars_test_v1_test_proto_rawDescData []byte
)

func file_tars_test_v1_test_proto_rawDescGZIP() []byte {
	file_tars_test_v1_test_proto_rawDescOnce.Do(func() {
		file_tars_test_v1_test_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_tars_test_v1_test_proto_rawDesc), len(file_tars_test_v1_test_proto_rawDesc)))
	})
	return file_tars_test_v1_test_proto_rawDescData
}

var file_tars_test_v1_test_proto_msgTypes = make([]protoimpl.MessageInfo, 3)
var file_tars_test_v1_test_proto_goTypes = []any{
	(*PingRequest)(nil),           // 0: tars.test.v1.PingRequest
	(*PingResponse)(nil),          // 1: tars.test.v1.PingResponse
	nil,                           // 2: tars.test.v1.PingResponse.CustomClaimsEntry
	(*timestamppb.Timestamp)(nil), // 3: google.protobuf.Timestamp
}
var file_tars_test_v1_test_proto_depIdxs = []int32{
	3, // 0: tars.test.v1.PingResponse.expires_at:type_name -> google.protobuf.Timestamp
	3, // 1: tars.test.v1.PingResponse.issued_at:type_name -> google.protobuf.Timestamp
	3, // 2: tars.test.v1.PingResponse.server_time:type_name -> google.protobuf.Timestamp
	2, // 3: tars.test.v1.PingResponse.custom_claims:type_name -> tars.test.v1.PingResponse.CustomClaimsEntry
	0, // 4: tars.test.v1.TestService.Ping:input_type -> tars.test.v1.PingRequest
	1, // 5: tars.test.v1.TestService.Ping:output_type -> tars.test.v1.PingResponse
	5, // [5:6] is the sub-list for method output_type
	4, // [4:5] is the sub-list for method input_type
	4, // [4:4] is the sub-list for extension type_name
	4, // [4:4] is the sub-list for extension extendee
	0, // [0:4] is the sub-list for field type_name
}

func init() { file_tars_test_v1_test_proto_init() }
func file_tars_test_v1_test_proto_init() {
	if File_tars_test_v1_test_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_tars_test_v1_test_proto_rawDesc), len(file_tars_test_v1_test_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   3,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_tars_test_v1_test_proto_goTypes,
		DependencyIndexes: file_tars_test_v1_test_proto_depIdxs,
		MessageInfos:      file_tars_test_v1_test_proto_msgTypes,
	}.Build()
	File_tars_test_v1_test_proto = out.File
	file_tars_test_v1_test_proto_goTypes = nil
	file_tars_test_v1_test_proto_depIdxs = nil
}
