// Code generated by protoc-gen-connect-go. DO NOT EDIT.
//
// Source: tars/auth/v1/auth.proto

package authv1connect

import (
	connect "connectrpc.com/connect"
	context "context"
	errors "errors"
	v1 "github.com/tetrateio/agentrouter-go/genapi/api/tars/auth/v1"
	http "net/http"
	strings "strings"
)

// This is a compile-time assertion to ensure that this generated file and the connect package are
// compatible. If you get a compiler error that this constant is not defined, this code was
// generated with a version of connect newer than the one compiled into your binary. You can fix the
// problem by either regenerating this code with an older version of connect or updating the connect
// version compiled into your binary.
const _ = connect.IsAtLeastVersion1_13_0

const (
	// AuthServiceName is the fully-qualified name of the AuthService service.
	AuthServiceName = "tars.auth.v1.AuthService"
)

// These constants are the fully-qualified names of the RPCs defined in this package. They're
// exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
//
// Note that these are different from the fully-qualified method names used by
// google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to
// reflection-formatted method names, remove the leading slash and convert the remaining slash to a
// period.
const (
	// AuthServiceGetJWKSProcedure is the fully-qualified name of the AuthService's GetJWKS RPC.
	AuthServiceGetJWKSProcedure = "/tars.auth.v1.AuthService/GetJWKS"
)

// AuthServiceClient is a client for the tars.auth.v1.AuthService service.
type AuthServiceClient interface {
	// JWKS endpoint.
	// Public endpoint - no authentication required.
	// Returns JSON Web Key Set for verifying JWT tokens.
	GetJWKS(context.Context, *connect.Request[v1.GetJWKSRequest]) (*connect.Response[v1.GetJWKSResponse], error)
}

// NewAuthServiceClient constructs a client for the tars.auth.v1.AuthService service. By default, it
// uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends
// uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or
// connect.WithGRPCWeb() options.
//
// The URL supplied here should be the base URL for the Connect or gRPC server (for example,
// http://api.acme.com or https://acme.com/grpc).
func NewAuthServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) AuthServiceClient {
	baseURL = strings.TrimRight(baseURL, "/")
	authServiceMethods := v1.File_tars_auth_v1_auth_proto.Services().ByName("AuthService").Methods()
	return &authServiceClient{
		getJWKS: connect.NewClient[v1.GetJWKSRequest, v1.GetJWKSResponse](
			httpClient,
			baseURL+AuthServiceGetJWKSProcedure,
			connect.WithSchema(authServiceMethods.ByName("GetJWKS")),
			connect.WithIdempotency(connect.IdempotencyNoSideEffects),
			connect.WithClientOptions(opts...),
		),
	}
}

// authServiceClient implements AuthServiceClient.
type authServiceClient struct {
	getJWKS *connect.Client[v1.GetJWKSRequest, v1.GetJWKSResponse]
}

// GetJWKS calls tars.auth.v1.AuthService.GetJWKS.
func (c *authServiceClient) GetJWKS(ctx context.Context, req *connect.Request[v1.GetJWKSRequest]) (*connect.Response[v1.GetJWKSResponse], error) {
	return c.getJWKS.CallUnary(ctx, req)
}

// AuthServiceHandler is an implementation of the tars.auth.v1.AuthService service.
type AuthServiceHandler interface {
	// JWKS endpoint.
	// Public endpoint - no authentication required.
	// Returns JSON Web Key Set for verifying JWT tokens.
	GetJWKS(context.Context, *connect.Request[v1.GetJWKSRequest]) (*connect.Response[v1.GetJWKSResponse], error)
}

// NewAuthServiceHandler builds an HTTP handler from the service implementation. It returns the path
// on which to mount the handler and the handler itself.
//
// By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf
// and JSON codecs. They also support gzip compression.
func NewAuthServiceHandler(svc AuthServiceHandler, opts ...connect.HandlerOption) (string, http.Handler) {
	authServiceMethods := v1.File_tars_auth_v1_auth_proto.Services().ByName("AuthService").Methods()
	authServiceGetJWKSHandler := connect.NewUnaryHandler(
		AuthServiceGetJWKSProcedure,
		svc.GetJWKS,
		connect.WithSchema(authServiceMethods.ByName("GetJWKS")),
		connect.WithIdempotency(connect.IdempotencyNoSideEffects),
		connect.WithHandlerOptions(opts...),
	)
	return "/tars.auth.v1.AuthService/", http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
		switch r.URL.Path {
		case AuthServiceGetJWKSProcedure:
			authServiceGetJWKSHandler.ServeHTTP(w, r)
		default:
			http.NotFound(w, r)
		}
	})
}

// UnimplementedAuthServiceHandler returns CodeUnimplemented from all methods.
type UnimplementedAuthServiceHandler struct{}

func (UnimplementedAuthServiceHandler) GetJWKS(context.Context, *connect.Request[v1.GetJWKSRequest]) (*connect.Response[v1.GetJWKSResponse], error) {
	return nil, connect.NewError(connect.CodeUnimplemented, errors.New("tars.auth.v1.AuthService.GetJWKS is not implemented"))
}
