// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.10
// 	protoc        (unknown)
// source: tars/auth/v1/auth.proto

package authv1

import (
	_ "google.golang.org/genproto/googleapis/api/annotations"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type GetJWKSRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetJWKSRequest) Reset() {
	*x = GetJWKSRequest{}
	mi := &file_tars_auth_v1_auth_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetJWKSRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetJWKSRequest) ProtoMessage() {}

func (x *GetJWKSRequest) ProtoReflect() protoreflect.Message {
	mi := &file_tars_auth_v1_auth_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetJWKSRequest.ProtoReflect.Descriptor instead.
func (*GetJWKSRequest) Descriptor() ([]byte, []int) {
	return file_tars_auth_v1_auth_proto_rawDescGZIP(), []int{0}
}

// JWKS response containing public keys for JWT verification.
type GetJWKSResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Set of public JWKs available for verifying JWT signatures.
	Keys          []*JWK `protobuf:"bytes,1,rep,name=keys,proto3" json:"keys,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetJWKSResponse) Reset() {
	*x = GetJWKSResponse{}
	mi := &file_tars_auth_v1_auth_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetJWKSResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetJWKSResponse) ProtoMessage() {}

func (x *GetJWKSResponse) ProtoReflect() protoreflect.Message {
	mi := &file_tars_auth_v1_auth_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetJWKSResponse.ProtoReflect.Descriptor instead.
func (*GetJWKSResponse) Descriptor() ([]byte, []int) {
	return file_tars_auth_v1_auth_proto_rawDescGZIP(), []int{1}
}

func (x *GetJWKSResponse) GetKeys() []*JWK {
	if x != nil {
		return x.Keys
	}
	return nil
}

// JSON Web Key (JWK) representation for ECDSA keys.
type JWK struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Key ID: fingerprint of the public key.
	Kid string `protobuf:"bytes,1,opt,name=kid,proto3" json:"kid,omitempty"`
	// Key type: always "EC" (Elliptic Curve).
	Kty string `protobuf:"bytes,2,opt,name=kty,proto3" json:"kty,omitempty"`
	// Algorithm: "ES256", "ES384", or "ES512".
	Alg string `protobuf:"bytes,3,opt,name=alg,proto3" json:"alg,omitempty"`
	// Public key use: "sig" (signature).
	Use string `protobuf:"bytes,4,opt,name=use,proto3" json:"use,omitempty"`
	// EC curve name: "P-256", "P-384", or "P-521".
	Crv string `protobuf:"bytes,5,opt,name=crv,proto3" json:"crv,omitempty"`
	// EC public key x coordinate (base64url-encoded).
	X string `protobuf:"bytes,6,opt,name=x,proto3" json:"x,omitempty"`
	// EC public key y coordinate (base64url-encoded).
	Y             string `protobuf:"bytes,7,opt,name=y,proto3" json:"y,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *JWK) Reset() {
	*x = JWK{}
	mi := &file_tars_auth_v1_auth_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *JWK) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*JWK) ProtoMessage() {}

func (x *JWK) ProtoReflect() protoreflect.Message {
	mi := &file_tars_auth_v1_auth_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use JWK.ProtoReflect.Descriptor instead.
func (*JWK) Descriptor() ([]byte, []int) {
	return file_tars_auth_v1_auth_proto_rawDescGZIP(), []int{2}
}

func (x *JWK) GetKid() string {
	if x != nil {
		return x.Kid
	}
	return ""
}

func (x *JWK) GetKty() string {
	if x != nil {
		return x.Kty
	}
	return ""
}

func (x *JWK) GetAlg() string {
	if x != nil {
		return x.Alg
	}
	return ""
}

func (x *JWK) GetUse() string {
	if x != nil {
		return x.Use
	}
	return ""
}

func (x *JWK) GetCrv() string {
	if x != nil {
		return x.Crv
	}
	return ""
}

func (x *JWK) GetX() string {
	if x != nil {
		return x.X
	}
	return ""
}

func (x *JWK) GetY() string {
	if x != nil {
		return x.Y
	}
	return ""
}

var File_tars_auth_v1_auth_proto protoreflect.FileDescriptor

const file_tars_auth_v1_auth_proto_rawDesc = "" +
	"\n" +
	"\x17tars/auth/v1/auth.proto\x12\ftars.auth.v1\x1a\x1cgoogle/api/annotations.proto\"\x10\n" +
	"\x0eGetJWKSRequest\"8\n" +
	"\x0fGetJWKSResponse\x12%\n" +
	"\x04keys\x18\x01 \x03(\v2\x11.tars.auth.v1.JWKR\x04keys\"{\n" +
	"\x03JWK\x12\x10\n" +
	"\x03kid\x18\x01 \x01(\tR\x03kid\x12\x10\n" +
	"\x03kty\x18\x02 \x01(\tR\x03kty\x12\x10\n" +
	"\x03alg\x18\x03 \x01(\tR\x03alg\x12\x10\n" +
	"\x03use\x18\x04 \x01(\tR\x03use\x12\x10\n" +
	"\x03crv\x18\x05 \x01(\tR\x03crv\x12\f\n" +
	"\x01x\x18\x06 \x01(\tR\x01x\x12\f\n" +
	"\x01y\x18\a \x01(\tR\x01y2x\n" +
	"\vAuthService\x12i\n" +
	"\aGetJWKS\x12\x1c.tars.auth.v1.GetJWKSRequest\x1a\x1d.tars.auth.v1.GetJWKSResponse\"!\x82\xd3\xe4\x93\x02\x18\x12\x16/.well-known/jwks.json\x90\x02\x01B\xa4\x01\n" +
	"\x10com.tars.auth.v1B\tAuthProtoP\x01Z3github.com/tetrateio/fraser/api/tars/auth/v1;authv1\xa2\x02\x03TAX\xaa\x02\fTars.Auth.V1\xca\x02\fTars\\Auth\\V1\xe2\x02\x18Tars\\Auth\\V1\\GPBMetadata\xea\x02\x0eTars::Auth::V1b\x06proto3"

var (
	file_tars_auth_v1_auth_proto_rawDescOnce sync.Once
	file_tars_auth_v1_auth_proto_rawDescData []byte
)

func file_tars_auth_v1_auth_proto_rawDescGZIP() []byte {
	file_tars_auth_v1_auth_proto_rawDescOnce.Do(func() {
		file_tars_auth_v1_auth_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_tars_auth_v1_auth_proto_rawDesc), len(file_tars_auth_v1_auth_proto_rawDesc)))
	})
	return file_tars_auth_v1_auth_proto_rawDescData
}

var file_tars_auth_v1_auth_proto_msgTypes = make([]protoimpl.MessageInfo, 3)
var file_tars_auth_v1_auth_proto_goTypes = []any{
	(*GetJWKSRequest)(nil),  // 0: tars.auth.v1.GetJWKSRequest
	(*GetJWKSResponse)(nil), // 1: tars.auth.v1.GetJWKSResponse
	(*JWK)(nil),             // 2: tars.auth.v1.JWK
}
var file_tars_auth_v1_auth_proto_depIdxs = []int32{
	2, // 0: tars.auth.v1.GetJWKSResponse.keys:type_name -> tars.auth.v1.JWK
	0, // 1: tars.auth.v1.AuthService.GetJWKS:input_type -> tars.auth.v1.GetJWKSRequest
	1, // 2: tars.auth.v1.AuthService.GetJWKS:output_type -> tars.auth.v1.GetJWKSResponse
	2, // [2:3] is the sub-list for method output_type
	1, // [1:2] is the sub-list for method input_type
	1, // [1:1] is the sub-list for extension type_name
	1, // [1:1] is the sub-list for extension extendee
	0, // [0:1] is the sub-list for field type_name
}

func init() { file_tars_auth_v1_auth_proto_init() }
func file_tars_auth_v1_auth_proto_init() {
	if File_tars_auth_v1_auth_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_tars_auth_v1_auth_proto_rawDesc), len(file_tars_auth_v1_auth_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   3,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_tars_auth_v1_auth_proto_goTypes,
		DependencyIndexes: file_tars_auth_v1_auth_proto_depIdxs,
		MessageInfos:      file_tars_auth_v1_auth_proto_msgTypes,
	}.Build()
	File_tars_auth_v1_auth_proto = out.File
	file_tars_auth_v1_auth_proto_goTypes = nil
	file_tars_auth_v1_auth_proto_depIdxs = nil
}
